@@ -1,8 +1,8 @@
 /*!-----------------------------------------------------------
  * Copyright (c) Microsoft Corporation. All rights reserved.
- * Version: 0.21.3(b251bd952b84a3bdf68dad0141c37137dac55d64)
+ * Version: 0.25.1(336c463ee6c20d8a49e40d099b9178def0df6b18)
  * Released under the MIT license
- * https://github.com/Microsoft/vscode/blob/master/LICENSE.txt
+ * https://github.com/microsoft/vscode/blob/main/LICENSE.txt
  *-----------------------------------------------------------*/
 
 define("vs/editor/editor.main.nls.ja", {
@@ -21,6 +21,9 @@ define("vs/editor/editor.main.nls.ja", {
 		"入力",
 		"保持する",
 	],
+	"vs/base/browser/ui/iconLabel/iconLabelHover": [
+		"読み込み中...",
+	],
 	"vs/base/browser/ui/inputbox/inputBox": [
 		"エラー: {0}",
 		"警告: {0}",
@@ -39,6 +42,9 @@ define("vs/editor/editor.main.nls.ja", {
 		"要素が見つかりません",
 		"{1} 個の要素のうち {0} 個の要素が一致しました",
 	],
+	"vs/base/common/actions": [
+		"(空)",
+	],
 	"vs/base/common/errorMessage": [
 		"{0}: {1}",
 		"システム エラーが発生しました ({0})",
@@ -71,6 +77,7 @@ define("vs/editor/editor.main.nls.ja", {
 	],
 	"vs/base/parts/quickinput/browser/quickInput": [
 		"戻る",
+		"\'Enter\' を押して入力を確認するか \'Escape\' を押して取り消します",
 		"{0}/{1}",
 		"入力すると結果が絞り込まれます。",
 		"{0} 件の結果",
@@ -86,11 +93,15 @@ define("vs/editor/editor.main.nls.ja", {
 	"vs/editor/browser/controller/coreCommands": [
 		"長い行に移動しても行末に位置します",
 		"長い行に移動しても行末に位置します",
+		"セカンダリ カーソルが削除されました",
 	],
 	"vs/editor/browser/controller/textAreaHandler": [
 		"エディター",
 		"この時点では、エディターにアクセスできません。オプションを表示するには、{0} を押します。",
 	],
+	"vs/editor/browser/core/keybindingCancellation": [
+		"エディターで取り消し可能な操作 (\'参照をここに表示\' など) を実行するかどうか",
+	],
 	"vs/editor/browser/editorExtensions": [
 		"元に戻す(&&U)",
 		"元に戻す",
@@ -103,9 +114,14 @@ define("vs/editor/editor.main.nls.ja", {
 		"カーソルの数は {0} 個に制限されています。",
 	],
 	"vs/editor/browser/widget/diffEditorWidget": [
+		"差分エディターで挿入を示す線の装飾。",
+		"差分エディターで削除を示す線の装飾。",
 		"一方のファイルが大きすぎるため、ファイルを比較できません。",
 	],
 	"vs/editor/browser/widget/diffReview": [
+		"差分レビューでの \'挿入\' のアイコン。",
+		"差分レビューでの \'削除\' のアイコン。",
+		"差分レビューでの \'閉じる\' のアイコン。",
 		"閉じる",
 		"変更された行はありません",
 		"1 行が変更されました",
@@ -134,6 +150,10 @@ define("vs/editor/editor.main.nls.ja", {
 		"自動挿入された末尾の空白を削除します。",
 		"大きなファイルでメモリが集中する特定の機能を無効にするための特別な処理。",
 		"ドキュメント内の単語に基づいて入力候補を計算するかどうかを制御します。",
+		"アクティブなドキュメントからのみ単語の候補を表示します。",
+		"同じ言語の開いているすべてのドキュメントから単語の候補を表示します。",
+		"開いているすべてのドキュメントから単語の候補を表示します。",
+		"単語ベースの入力候補が計算されるドキュメントを制御します。",
 		"セマンティックの強調表示がすべての配色テーマについて有効になりました。",
 		"セマンティックの強調表示がすべての配色テーマについて無効になりました。",
 		"セマンティックの強調表示は、現在の配色テーマの \'semanticHighlighting\' 設定によって構成されています。",
@@ -145,6 +165,9 @@ define("vs/editor/editor.main.nls.ja", {
 		"有効にすると、差分エディターは先頭または末尾の空白文字の変更を無視します。",
 		"差分エディターが追加/削除された変更に +/- インジケーターを示すかどうかを制御します。",
 		"エディターで CodeLens を表示するかどうかを制御します。",
+		"行を折り返しません。",
+		"行をビューポートの幅で折り返します。",
+		"行は、`#editor.wordWrap#` 設定に従って折り返されます。",
 	],
 	"vs/editor/common/config/editorOptions": [
 		"エディターはスクリーン リーダーがいつ接続されたかを検出するためにプラットフォーム API を使用します。",
@@ -156,16 +179,16 @@ define("vs/editor/editor.main.nls.ja", {
 		"選択範囲を指定しないでコピーする場合に現在の行をコピーするかどうかを制御します。",
 		"入力中に一致を検索するためにカーソルをジャンプさせるかどうかを制御します。",
 		"エディターの選択範囲から検索ウィジェット内の検索文字列を与えるかどうかを制御します。",
-		"[選択範囲を検索] を自動的にオンにしない (既定)",
-		"[選択範囲を検索] を常に自動的にオンにする",
+		"[選択範囲を検索] を自動的にオンにしません (既定)。",
+		"[選択範囲を検索] を常に自動的にオンにします。",
 		"複数行のコンテンツが選択されている場合は、自動的に [選択範囲を検索] をオンにします。",
 		"[選択範囲を検索] を自動的にオンにする条件を制御します。",
 		"macOS で検索ウィジェットが共有の検索クリップボードを読み取りまたは変更するかどうかを制御します。",
 		"検索ウィジェットがエディターの上に行をさらに追加するかどうかを制御します。true の場合、検索ウィジェットが表示されているときに最初の行を超えてスクロールできます。",
 		"以降で一致が見つからない場合に、検索を先頭から (または末尾から) 自動的に再実行するかどうか制御します。",
-		"フォントの合字を有効/無効にします。",
-		"明示的なフォント機能設定。",
-		"フォントの合字またはフォントの機能を構成します。",
+		"フォントの合字 (\'calt\' および \'liga\' フォントの機能) を有効または無効にします。\'font-feature-settings\' CSS プロパティを詳細に制御するには、これを文字列に変更します。",
+		"明示的な \'font-feature-settings\' CSS プロパティ。合字を有効または無効にする必要があるのが 1 つだけである場合は、代わりにブール値を渡すことができます。",
+		"フォントの合字やフォントの機能を構成します。合字を有効または無効にするブール値または CSS \'font-feature-settings\' プロパティの値の文字列を指定できます。",
 		"フォント サイズ (ピクセル単位) を制御します。",
 		"使用できるのは \"標準\" および \"太字\" のキーワードまたは 1 ～ 1000 の数字のみです。",
 		"フォントの太さを制御します。\"標準\" および \"太字\" のキーワードまたは 1 ～ 1000 の数字を受け入れます。",
@@ -187,6 +210,9 @@ define("vs/editor/editor.main.nls.ja", {
 		"ホバーを表示後の待ち時間 (ミリ秒) を制御します。",
 		"ホバーにマウスを移動したときに、ホバーを表示し続けるかどうかを制御します。",
 		"エディターでコード アクションの電球を有効にします。",
+		"エディターでインレー ヒントを有効にします。",
+		"エディターでインレー ヒントのフォント サイズを制御します。\'0\' に設定すると、`#editor.fontSize#` の 90% が使用されます。",
+		"エディターでインレー ヒントのフォント ファミリを制御します。",
 		"行の高さを制御します。フォント サイズに基づいて行の高さを計算する場合には、0 を使用します。",
 		"ミニマップを表示するかどうかを制御します。",
 		"ミニマップのサイズは、エディターのコンテンツと同じです (スクロールする場合があります)。",
@@ -214,6 +240,7 @@ define("vs/editor/editor.main.nls.ja", {
 		"このエディターのルーラーがレンダリングする単一領域の文字数。",
 		"このエディターのルーラーの色です。",
 		"特定の等幅文字数の後に垂直ルーラーを表示します。複数のルーラーには複数の値を使用します。配列が空の場合はルーラーを表示しません。",
+		"エディターにインライン候補を自動的に表示するかどうかを制御します。",
 		"カーソルの右のテキストを上書きせずに候補を挿入します。",
 		"候補を挿入し、カーソルの右のテキストを上書きします。",
 		"入力候補を受け入れるときに単語を上書きするかどうかを制御します。これは、この機能の利用を選択する拡張機能に依存することにご注意ください。",
@@ -222,11 +249,15 @@ define("vs/editor/editor.main.nls.ja", {
 		"保存された候補セクションを複数のワークプレースとウィンドウで共有するかどうかを制御します (`#editor.suggestSelection#` が必要)。",
 		"アクティブ スニペットがクイック候補を防止するかどうかを制御します。",
 		"提案のアイコンを表示するか、非表示にするかを制御します。",
-		"スクロール バーを表示する前に IntelliSense が表示する候補の数を制御します (最大 15 個)。",
+		"候補ウィジェットの下部にあるステータス バーの表示を制御します。",
+		"提案の結果をエディターでプレビューするかどうかを制御します。",
+		"候補の詳細をラベル付きのインラインで表示するか、詳細ウィジェットにのみ表示するかを制御します",
+		"この設定は非推奨です。候補ウィジェットのサイズ変更ができるようになりました。",
 		"この設定は非推奨です。代わりに、\'editor.suggest.showKeywords\' や \'editor.suggest.showSnippets\' などの個別の設定を使用してください。",
 		"有効にすると、IntelliSense に `メソッド` 候補が表示されます。",
 		"有効にすると、IntelliSense に `関数` 候補が表示されます。",
 		"有効にすると、IntelliSense に `コンストラクター` 候補が表示されます。",
+		"有効にすると、IntelliSense に `非推奨` 候補が表示されます。",
 		"有効にすると、IntelliSense に `フィールド` 候補が表示されます。",
 		"有効にすると、IntelliSense に `変数` 候補が表示されます。",
 		"有効にすると、IntelliSense に \'クラス\' 候補が表示されます。",
@@ -252,15 +283,17 @@ define("vs/editor/editor.main.nls.ja", {
 		"有効にすると、IntelliSense に `スニペット` 候補が表示されます。",
 		"有効な場合、IntelliSense によって \'ユーザー\' 候補が示されます。",
 		"有効にすると、IntelliSense によって \'問題\' 候補が示されます。",
-		"候補ウィジェットの下部にあるステータス バーの表示を制御します。",
+		"先頭と末尾の空白を常に選択するかどうか。",
 		"コミット文字で候補を受け入れるかどうかを制御します。たとえば、JavaScript ではセミコロン (`;`) をコミット文字にして、候補を受け入れてその文字を入力することができます。",
 		"テキストの変更を行うとき、`Enter` を使用する場合にのみ候補を受け付けます。",
 		"`Tab` キーに加えて `Enter` キーで候補を受け入れるかどうかを制御します。改行の挿入や候補の反映の間であいまいさを解消するのに役立ちます。",
-		"スクリーン リーダーで読み上げることができるエディターの行数を制御します。警告: 既定値を上回る数を指定すると、パフォーマンスに影響を与えます。",
+		"一度にスクリーン リーダーによって読み上げることができるエディターの行数を制御します。スクリーン リーダーが検出されると、既定値が 500 に自動的に設定されます。警告: 既定値より大きい数値の場合は、パフォーマンスに影響があります。",
 		"エディターのコンテンツ",
 		"言語設定を使用して、いつかっこを自動クローズするか決定します。",
 		"カーソルが空白文字の左にあるときだけ、かっこを自動クローズします。",
 		"エディターで左角かっこを追加した後に自動的に右角かっこを挿入するかどうかを制御します。",
+		"隣接する終わり引用符または括弧が自動的に挿入された場合にのみ、それらを削除します。",
+		"削除時にエディターで隣接する終わり引用符または括弧を削除するかどうかを制御します。",
 		"終わり引用符または括弧が自動的に挿入された場合にのみ、それらを上書きします。",
 		"エディターで終わり引用符または括弧を上書きするかどうかを制御します。",
 		"言語設定を使用して、いつ引用符を自動クローズするか決定します。",
@@ -276,7 +309,10 @@ define("vs/editor/editor.main.nls.ja", {
 		"角かっこではなく、引用符で囲みます。",
 		"引用符ではなく、角かっこで囲みます。",
 		"引用符または角かっこを入力するときに、エディターが選択範囲を自動的に囲むかどうかを制御します。",
+		"インデントにスペースを使用するときは、タブ文字の選択動作をエミュレートします。選択範囲はタブ位置に留まります。",
 		"エディターで CodeLens を表示するかどうかを制御します。",
+		"CodeLens のフォント ファミリを制御します。",
+		"CodeLens のフォント サイズをピクセル単位で制御します。\'0\' に設定すると、\'#editor.fontSize#\' の 90% が使用されます。",
 		"エディターでインライン カラー デコレーターと色の選択を表示する必要があるかどうかを制御します。",
 		"マウスとキーでの選択により列の選択を実行できるようにします。",
 		"構文ハイライトをクリップボードにコピーするかどうかを制御します。",
@@ -303,6 +339,7 @@ define("vs/editor/editor.main.nls.ja", {
 		"概要ルーラーでカーソルを非表示にするかどうかを制御します。",
 		"エディターでアクティブなインデントのガイドを強調表示するかどうかを制御します。",
 		"文字間隔 (ピクセル単位) を制御します。",
+		"リンクされた編集がエディターで有効にされるかどうかを制御します。言語によっては、編集中に HTML タグなどの関連する記号が更新されます。",
 		"エディターがリンクを検出してクリック可能な状態にするかどうかを制御します。",
 		"対応するかっこを強調表示します。",
 		"マウス ホイール スクロール イベントの `deltaX` と `deltaY` で使用される乗数。",
@@ -322,15 +359,16 @@ define("vs/editor/editor.main.nls.ja", {
 		"[定義へ移動] マウス ジェスチャーで、常にピーク ウィジェットを開くかどうかを制御します。",
 		"クイック候補が表示されるまでのミリ秒を制御します。",
 		"エディターでの型の自動名前変更を制御します。",
+		"非推奨です。代わりに、`editor.linkedEditing` を使用してください。",
 		"エディターで制御文字を表示するかどうかを制御します。",
 		"エディターでインデント ガイドを表示するかどうかを制御します。",
 		"ファイルの末尾が改行の場合は、最後の行番号を表示します。",
 		"余白と現在の行を強調表示します。",
 		"エディターが現在の行をどのように強調表示するかを制御します。",
-		"エディターにフォーカスがある場合にのみ現在の行をエディターで強調表示する必要があるかどうかを制御します",
+		"エディターにフォーカスがある場合にのみ現在の行をエディターで強調表示する必要があるかどうかを制御します。",
 		"単語間の単一スペース以外の空白文字を表示します。",
 		"選択したテキストにのみ空白文字を表示します。",
-		"末尾の空白文字のみを表示する",
+		"末尾の空白文字のみを表示します。",
 		"エディターで空白文字を表示するかどうかを制御します。",
 		"選択範囲の角を丸くするかどうかを制御します。",
 		"エディターが水平方向に余分にスクロールする文字数を制御します。",
@@ -350,7 +388,7 @@ define("vs/editor/editor.main.nls.ja", {
 		"他の修正候補と一緒にスニペットを表示するかどうか、およびその並び替えの方法を制御します。",
 		"アニメーションでエディターをスクロールするかどうかを制御します。",
 		"候補ウィジェットのフォント サイズ。`0` に設定すると、`#editor.fontSize#` の値が使用されます。",
-		"候補ウィジェットの行の高さ。`0` に設定すると、`#editor.lineHeight#` の値が使用されます。",
+		"候補ウィジェットの行の高さ。`0` に設定すると、`#editor.lineHeight#` の値が使用されます。最小値は 8 です。",
 		"トリガー文字の入力時に候補が自動的に表示されるようにするかどうかを制御します。",
 		"常に最初の候補を選択します。",
 		"`console.| -> console.log` などと選択対象に関して入力しない限りは、最近の候補を選択します。`log` は最近完了したためです。",
@@ -360,9 +398,9 @@ define("vs/editor/editor.main.nls.ja", {
 		"タブ補完を無効にします。",
 		"プレフィックスが一致する場合に、タブでスニペットを補完します。\'quickSuggestions\' が無効な場合に最適です。",
 		"タブ補完を有効にします。",
+		"通常とは異なる行の終端文字は自動的に削除される。",
 		"通常とは異なる行の終端文字は無視される。",
 		"通常とは異なる行の終端文字の削除プロンプトが表示される。",
-		"通常とは異なる行の終端文字は自動的に削除される。",
 		"問題を起こす可能性がある、普通ではない行終端記号は削除してください。",
 		"空白の挿入や削除はタブ位置に従って行われます。",
 		"単語に関連したナビゲーションまたは操作を実行するときに、単語の区切り文字として使用される文字。",
@@ -381,6 +419,38 @@ define("vs/editor/editor.main.nls.ja", {
 		"折り返しポイントの計算をブラウザーにデリゲートします。これは、大きなファイルのフリーズを引き起こす可能性があるものの、すべてのケースで正しく動作する低速なアルゴリズムです。",
 		"折り返しポイントを計算するアルゴリズムを制御します。",
 	],
+	"vs/editor/common/editorContextKeys": [
+		"エディターのテキストにフォーカスがある (カーソルが点滅している) かどうか",
+		"エディターまたはエディター ウィジェットにフォーカスがある (例: 検索ウィジェットにフォーカスがある) かどうか",
+		"エディターまたはリッチ テキスト入力にフォーカスがある (カーソルが点滅している) かどうか",
+		"エディターが読み取り専用かどうか",
+		"コンテキストが差分エディターであるかどうか",
+		"`editor.columnSelection` が有効になっているかどうか",
+		"エディターでテキストが選択されているかどうか",
+		"エディターに複数の選択範囲があるかどうか",
+		"`Tab` によってフォーカスがエディターの外に移動するかどうか",
+		"エディターのホバーが表示されているかどうか",
+		"エディターがより大きなエディター (例: Notebooks) の一部であるかどうか",
+		"エディターの言語識別子",
+		"エディターに入力候補項目プロバイダーがあるかどうか",
+		"エディターにコード アクション プロバイダーがあるかどうか",
+		"エディターにコード レンズ プロバイダーがあるかどうか",
+		"エディターに定義プロバイダーがあるかどうか",
+		"エディターに宣言プロバイダーがあるかどうか",
+		"エディターに実装プロバイダーがあるかどうか",
+		"エディターに型定義プロバイダーがあるかどうか",
+		"エディターにホバー プロバイダーがあるかどうか",
+		"エディターにドキュメント強調表示プロバイダーがあるかどうか",
+		"エディターにドキュメント シンボル プロバイダーがあるかどうか",
+		"エディターに参照プロバイダーがあるかどうか",
+		"エディターに名前変更プロバイダーがあるかどうか",
+		"エディターにシグネチャ ヘルプ プロバイダーがあるかどうか",
+		"エディターにインライン ヒント プロバイダーがあるかどうか",
+		"エディターにドキュメント書式設定プロバイダーがあるかどうか",
+		"エディターにドキュメント選択書式設定プロバイダーがあるかどうか",
+		"エディターに複数のドキュメント書式設定プロバイダーがあるかどうか",
+		"エディターに複数のドキュメント選択書式設定プロバイダーがあるかどうか",
+	],
 	"vs/editor/common/model/editStack": [
 		"入力しています",
 	],
@@ -417,7 +487,7 @@ define("vs/editor/editor.main.nls.ja", {
 		"コマンド パレット",
 		"コマンドの表示と実行",
 		"シンボルに移動...",
-		"カテゴリ別のシンボルへ移動",
+		"カテゴリ別のシンボルへ移動...",
 		"エディターのコンテンツ",
 		"アクティビティ オプションを表示するには、Alt+F1 キーを押します。",
 		"ハイ コントラスト テーマの切り替え",
@@ -448,6 +518,8 @@ define("vs/editor/editor.main.nls.ja", {
 		"エディターの余白の背景色。余白にはグリフ マージンと行番号が含まれます。",
 		"エディターでの不要な (未使用の) ソース コードの罫線の色。",
 		"エディター内の不要な (未使用の) ソース コードの不透明度。たとえば、\"#000000c0\" は不透明度 75% でコードを表示します。ハイ コントラストのテーマの場合、\'editorUnnecessaryCode.border\' テーマ色を使用して、不要なコードをフェードアウトするのではなく下線を付けます。",
+		"エディター内の透かし文字の境界線の色です。",
+		"エディターの透かし文字の前景色です。",
 		"範囲強調表示のための概要ルーラー マーカーの色。この色は、基本装飾が非表示にならないよう不透明にすることはできません。",
 		"エラーを示す概要ルーラーのマーカー色。",
 		"警告を示す概要ルーラーのマーカー色。",
@@ -478,12 +550,17 @@ define("vs/editor/editor.main.nls.ja", {
 		"切り取り(&&T)",
 		"切り取り",
 		"切り取り",
+		"切り取り",
 		"コピー(&&C)",
 		"コピー",
 		"コピー",
+		"コピー",
+		"名前を付けてコピー",
+		"名前を付けてコピー",
 		"貼り付け(&&P)",
 		"貼り付け",
 		"貼り付け",
+		"貼り付け",
 		"構文を強調表示してコピー",
 	],
 	"vs/editor/contrib/codeAction/codeActionCommands": [
@@ -540,48 +617,11 @@ define("vs/editor/editor.main.nls.ja", {
 		"カーソルを元に戻す",
 		"カーソルのやり直し",
 	],
-	"vs/editor/contrib/documentSymbols/outlineTree": [
-		"配列記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
-		"ブール値記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
-		"クラス記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
-		"色記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
-		"定数記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
-		"コンストラクター記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
-		"列挙子記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
-		"列挙子メンバー記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
-		"イベント記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
-		"フィールド記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
-		"ファイル記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
-		"フォルダー記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
-		"関数記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
-		"インターフェイス記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
-		"キー記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
-		"キーワード記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
-		"メソッド記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
-		"モジュール記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
-		"名前空間記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
-		"Null 記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
-		"数値記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
-		"オブジェクト記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
-		"演算子記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
-		"パッケージ記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
-		"プロパティ記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
-		"参照記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
-		"スニペット記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
-		"文字列記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
-		"構造体記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
-		"テキスト記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
-		"パラメーター記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
-		"単位記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
-		"変数記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
-	],
 	"vs/editor/contrib/find/findController": [
 		"検索",
 		"検索(&&F)",
 		"選択範囲で検索",
 		"次を検索",
-		"次を検索",
-		"前を検索",
 		"前を検索",
 		"次の選択項目を検索",
 		"前の選択項目を検索",
@@ -589,6 +629,13 @@ define("vs/editor/editor.main.nls.ja", {
 		"置換(&&R)",
 	],
 	"vs/editor/contrib/find/findWidget": [
+		"エディターの検索ウィジェット内の \'選択範囲を検索\' のアイコン。",
+		"エディターの検索ウィジェットが折りたたまれていることを示すアイコン。",
+		"エディターの検索ウィジェットが展開されていることを示すアイコン。",
+		"エディターの検索ウィジェット内の \'置換\' のアイコン。",
+		"エディターの検索ウィジェット内の \'すべて置換\' のアイコン。",
+		"エディターの検索ウィジェット内の \'前を検索\' のアイコン。",
+		"エディターの検索ウィジェット内の \'次を検索\' のアイコン。",
 		"検索",
 		"検索",
 		"前の検索結果",
@@ -618,12 +665,18 @@ define("vs/editor/editor.main.nls.ja", {
 		"すべてのブロック コメントの折りたたみ",
 		"すべての領域を折りたたむ",
 		"すべての領域を展開",
+		"選択されたものを除くすべての領域を折りたたむ",
+		"選択されたものを除くすべての領域を展開する",
 		"すべて折りたたみ",
 		"すべて展開",
 		"レベル {0} で折りたたむ",
 		"折り曲げる範囲の背景色。基の装飾を隠さないように、色は不透明であってはなりません。",
 		"エディターの余白にある折りたたみコントロールの色。",
 	],
+	"vs/editor/contrib/folding/foldingDecorations": [
+		"エディターのグリフ余白内の展開された範囲のアイコン。",
+		"エディターのグリフ余白内の折りたたまれた範囲のアイコン。",
+	],
 	"vs/editor/contrib/fontZoom/fontZoom": [
 		"エディターのフォントを拡大",
 		"エディターのフォントを縮小",
@@ -641,7 +694,9 @@ define("vs/editor/editor.main.nls.ja", {
 	],
 	"vs/editor/contrib/gotoError/gotoError": [
 		"次の問題 (エラー、警告、情報) へ移動",
+		"次のマーカーへ移動するためのアイコン。",
 		"前の問題 (エラー、警告、情報) へ移動",
+		"前のマーカーへ移動するためのアイコン。",
 		"ファイル内の次の問題 (エラー、警告、情報) へ移動",
 		"次の問題箇所(&&P)",
 		"ファイル内の前の問題 (エラー、警告、情報) へ移動",
@@ -705,6 +760,7 @@ define("vs/editor/editor.main.nls.ja", {
 		"クリックして、{0} の定義を表示します。",
 	],
 	"vs/editor/contrib/gotoSymbol/peek/referencesController": [
+		"参照のプレビューが表示されるかどうか (\'参照のプレビュー\' または \'定義をここに表示\' など)",
 		"読み込んでいます...",
 		"{0} ({1})",
 	],
@@ -720,6 +776,7 @@ define("vs/editor/editor.main.nls.ja", {
 	],
 	"vs/editor/contrib/gotoSymbol/referencesModel": [
 		"列 {2} の {1} 行目に {0} つのシンボル",
+		"列 {2}、{3} の {1} 行目の {0} にある記号",
 		"{0} に 1 個のシンボル、完全なパス {1}",
 		"{1} に {0} 個のシンボル、完全なパス {2}",
 		"一致する項目はありません",
@@ -728,6 +785,7 @@ define("vs/editor/editor.main.nls.ja", {
 		"{1} 個のファイルに {0} 個のシンボルが見つかりました",
 	],
 	"vs/editor/contrib/gotoSymbol/symbolNavigation": [
+		"キーボードのみで移動できるシンボルの場所があるかどうか。",
 		"{1} のシンボル {0}、次に {2}",
 		"シンボル {0}/{1}",
 	],
@@ -735,9 +793,12 @@ define("vs/editor/editor.main.nls.ja", {
 		"ホバーの表示",
 		"定義プレビューのホバーを表示する",
 	],
-	"vs/editor/contrib/hover/modesContentHover": [
+	"vs/editor/contrib/hover/markdownHoverParticipant": [
 		"読み込んでいます...",
-		"問題を表示",
+	],
+	"vs/editor/contrib/hover/markerHoverParticipant": [
+		"問題の表示",
+		"利用できるクイックフィックスはありません",
 		"クイックフィックスを確認しています...",
 		"利用できるクイックフィックスはありません",
 		"クイック フィックス...",
@@ -757,6 +818,18 @@ define("vs/editor/editor.main.nls.ja", {
 		"行の再インデント",
 		"選択行を再インデント",
 	],
+	"vs/editor/contrib/inlineCompletions/ghostTextController": [
+		"インライン候補を表示するかどうか",
+		"インライン候補がスペースで始まるかどうか",
+		"次のインライン候補を表示する",
+		"前のインライン候補を表示する",
+		"インライン候補をトリガーする",
+	],
+	"vs/editor/contrib/inlineCompletions/inlineCompletionsHoverParticipant": [
+		"次へ",
+		"前へ",
+		"同意する",
+	],
 	"vs/editor/contrib/linesOperations/linesOperations": [
 		"行を上へコピー",
 		"行を上へコピー(&&C)",
@@ -783,6 +856,11 @@ define("vs/editor/editor.main.nls.ja", {
 		"大文字に変換",
 		"小文字に変換",
 		"先頭文字を大文字に変換する",
+		"スネーク ケースに変換する",
+	],
+	"vs/editor/contrib/linkedEditing/linkedEditing": [
+		"リンクされた編集の開始",
+		"エディターが型の名前の自動変更を行うときの背景色です。",
 	],
 	"vs/editor/contrib/links/links": [
 		"コマンドの実行",
@@ -791,14 +869,18 @@ define("vs/editor/editor.main.nls.ja", {
 		"ctrl + クリック",
 		"option + クリック",
 		"alt + クリック",
+		"コマンド {0} の実行",
 		"このリンクは形式が正しくないため開くことができませんでした: {0}",
 		"このリンクはターゲットが存在しないため開くことができませんでした。",
 		"リンクを開く",
 	],
 	"vs/editor/contrib/message/messageController": [
+		"エディターに現在インライン メッセージが表示されているかどうか",
 		"読み取り専用のエディターは編集できません",
 	],
 	"vs/editor/contrib/multicursor/multicursor": [
+		"追加されたカーソル: {0}",
+		"追加されたカーソル: {0}",
 		"カーソルを上に挿入",
 		"カーソルを上に挿入(&&A)",
 		"カーソルを下に挿入",
@@ -821,9 +903,12 @@ define("vs/editor/editor.main.nls.ja", {
 		"パラメーター ヒントをトリガー",
 	],
 	"vs/editor/contrib/parameterHints/parameterHintsWidget": [
+		"次のパラメーター ヒントを表示するためのアイコン。",
+		"前のパラメーター ヒントを表示するためのアイコン。",
 		"{0}、ヒント",
 	],
 	"vs/editor/contrib/peekView/peekView": [
+		"現在のコード エディターがプレビュー内に埋め込まれるかどうか",
 		"閉じる",
 		"ピーク ビューのタイトル領域の背景色。",
 		"ピーク ビュー タイトルの色。",
@@ -842,7 +927,7 @@ define("vs/editor/editor.main.nls.ja", {
 	],
 	"vs/editor/contrib/quickAccess/gotoLineQuickAccess": [
 		"最初にテキスト エディターを開いて、行に移動します。",
-		"行 {0}、列 {1} に移動します。",
+		"行 {0}、文字 {1} に移動します。",
 		"{0} 行に移動します。",
 		"現在の行: {0}、文字: {1}。移動先となる、1 から {2} までの行番号を入力します。",
 		"現在の行: {0}、文字: {1}。移動先の行番号を入力します。",
@@ -882,10 +967,6 @@ define("vs/editor/editor.main.nls.ja", {
 		"フィールド ({0})",
 		"定数 ({0})",
 	],
-	"vs/editor/contrib/rename/onTypeRename": [
-		"シンボルの名前変更に入力時",
-		"エディターが型の名前の自動変更を行うときの背景色です。",
-	],
 	"vs/editor/contrib/rename/rename": [
 		"結果がありません。",
 		"名前変更の場所を解決しようとして不明なエラーが発生しました",
@@ -898,6 +979,7 @@ define("vs/editor/editor.main.nls.ja", {
 		"名前を変更する前に変更をプレビューする機能を有効または無効にする",
 	],
 	"vs/editor/contrib/rename/renameInputField": [
+		"名前の変更入力ウィジェットが表示されるかどうか",
 		"名前変更入力。新しい名前を入力し、Enter キーを押してコミットしてください。",
 		"名前を変更するには {0}、プレビューするには {1}",
 	],
@@ -907,6 +989,11 @@ define("vs/editor/editor.main.nls.ja", {
 		"選択範囲を縮小",
 		"選択範囲の縮小(&&S)",
 	],
+	"vs/editor/contrib/snippet/snippetController2": [
+		"現在のエディターがスニペット モードであるかどうか",
+		"スニペット モードのときに、次のタブ位置があるかどうか",
+		"スニペット モードのときに、前のタブ位置があるかどうか",
+	],
 	"vs/editor/contrib/snippet/snippetVariables": [
 		"日曜日",
 		"月曜日",
@@ -947,31 +1034,87 @@ define("vs/editor/editor.main.nls.ja", {
 		"11 月",
 		"12 月",
 	],
+	"vs/editor/contrib/suggest/suggest": [
+		"候補を表示するかどうか",
+		"候補の詳細が表示されるかどうか",
+		"選択する複数の候補があるかどうか",
+		"現在の候補を挿入したとき、変更を行うか、または既に入力した内容をすべて入力するかどうか",
+		"Enter キーを押したときに候補を挿入するかどうか",
+		"現在の候補に挿入と置換の動作があるかどうか",
+		"既定の動作が挿入または置換であるかどうか",
+		"現在の候補からの詳細の解決をサポートするかどうか",
+	],
 	"vs/editor/contrib/suggest/suggestController": [
-		"Accepting \'{0}\' made {1} additional edits",
+		"{1} が追加編集した \'{0}\' を受け入れる",
 		"候補をトリガー",
-		"挿入する {0}",
-		"{0}して挿入",
-		"{0}して置き換え",
-		"{0}して置き換え",
-		"{0}して挿入",
+		"挿入",
+		"挿入",
+		"置換",
+		"置換",
+		"挿入",
 		"表示を減らす",
 		"さらに表示",
+		"候補のウィジェットのサイズをリセット",
 	],
 	"vs/editor/contrib/suggest/suggestWidget": [
 		"候補のウィジェットの背景色。",
 		"候補ウィジェットの境界線色。",
 		"候補ウィジェットの前景色。",
+		"候補ウィジェット内で選択済み入力の前景色。",
 		"候補ウィジェット内で選択済みエントリの背景色。",
 		"候補のウィジェット内で一致したハイライトの色。",
-		"読み取り数を増やす ({0})",
-		"読み取り数を減らす ({0})",
-		"読み込んでいます...",
+		"項目がフォーカスされている場合に、候補ウィジェットでの一致の強調表示の色です。",
 		"読み込んでいます...",
 		"候補はありません。",
 		"{0}、ドキュメント: {1}",
 		"提案",
 	],
+	"vs/editor/contrib/suggest/suggestWidgetDetails": [
+		"閉じる",
+		"読み込んでいます...",
+	],
+	"vs/editor/contrib/suggest/suggestWidgetRenderer": [
+		"提案ウィジェットの詳細情報のアイコン。",
+		"詳細を参照",
+	],
+	"vs/editor/contrib/suggest/suggestWidgetStatus": [
+		"{0} ({1})",
+	],
+	"vs/editor/contrib/symbolIcons/symbolIcons": [
+		"配列記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
+		"ブール値記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
+		"クラス記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
+		"色記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
+		"定数記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
+		"コンストラクター記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
+		"列挙子記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
+		"列挙子メンバー記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
+		"イベント記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
+		"フィールド記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
+		"ファイル記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
+		"フォルダー記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
+		"関数記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
+		"インターフェイス記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
+		"キー記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
+		"キーワード記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
+		"メソッド記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
+		"モジュール記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
+		"名前空間記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
+		"Null 記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
+		"数値記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
+		"オブジェクト記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
+		"演算子記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
+		"パッケージ記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
+		"プロパティ記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
+		"参照記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
+		"スニペット記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
+		"文字列記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
+		"構造体記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
+		"テキスト記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
+		"パラメーター記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
+		"単位記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
+		"変数記号の前景色。これらの記号は、アウトライン、階層リンク、および候補のウィジェットに表示されます。",
+	],
 	"vs/editor/contrib/toggleTabFocusMode/toggleTabFocusMode": [
 		"Tab キーを切り替えるとフォーカスが移動します",
 		"Tab キーを押すと、次のフォーカス可能な要素にフォーカスを移動します",
@@ -998,16 +1141,27 @@ define("vs/editor/editor.main.nls.ja", {
 		"前のシンボル ハイライトに移動",
 		"シンボル ハイライトをトリガー",
 	],
+	"vs/editor/contrib/wordOperations/wordOperations": [
+		"単語の削除",
+	],
 	"vs/platform/actions/browser/menuEntryActionViewItem": [
 		"{0} ({1})",
+		"{0} ({1})",
 	],
 	"vs/platform/configuration/common/configurationRegistry": [
 		"既定の言語構成のオーバーライド",
 		"言語に対して上書きされるエディター設定を構成します。",
 		"この設定では、言語ごとの構成はサポートされていません。",
+		"空のプロパティは登録できません",
 		"\'{0}\' を登録できません。これは、言語固有のエディター設定を記述するプロパティ パターン \'\\\\[.*\\\\]$\' に一致しています。\'configurationDefaults\' コントリビューションを使用してください。",
 		"\'{0}\' を登録できません。このプロパティは既に登録されています。",
 	],
+	"vs/platform/contextkey/browser/contextKeyService": [
+		"コンテキスト キーに関する情報を返すコマンド",
+	],
+	"vs/platform/contextkey/common/contextkeys": [
+		"オペレーティング システムが Windows であるかどうか",
+	],
 	"vs/platform/keybinding/common/abstractKeybindingService": [
 		"({0}) が渡されました。2 番目のキーを待っています...",
 		"キーの組み合わせ ({0}、{1}) はコマンドではありません。",
@@ -1017,7 +1171,7 @@ define("vs/editor/editor.main.nls.ja", {
 		"Windows および Linux 上の `Control` キーと macOS 上の `Command` キーに割り当てます。",
 		"Windows および Linux 上の `Alt` キーと macOS 上の `Option` キーに割り当てます。",
 		"マウスを使用して項目を複数選択するときに使用する修飾キーです (たとえば、エクスプローラーでエディターと scm ビューを開くなど)。\'横に並べて開く\' マウス ジェスチャー (がサポートされている場合) は、複数選択の修飾キーと競合しないように調整されます。",
-		"マウスを使用して、ツリー リスト内の項目を開く方法を制御します (サポートされている場合)。ツリー内の子を持つ親項目で、この設定は親項目をシングル クリックで展開するか、ダブル クリックで展開するかどうかを制御します。この設定の選択 (適応するかどうか) を無視するツリー リストがあることに注意してください。",
+		"マウスを使用して、ツリーとリスト内の項目を開く方法を制御します (サポートされている場合)。適用できない場合、一部のツリーやリストではこの設定が無視されることがあります。",
 		"リストとツリーがワークベンチで水平スクロールをサポートするかどうかを制御します。警告: この設定をオンにすると、パフォーマンスに影響があります。",
 		"ツリーのインデントをピクセル単位で制御します。",
 		"ツリーでインシデントのガイドを表示する必要があるかどうかを制御します。",
@@ -1027,6 +1181,7 @@ define("vs/editor/editor.main.nls.ja", {
 		"キーボード ナビゲーションのフィルターでは、キーボード入力に一致しないすべての要素がフィルター処理され、非表示になります。",
 		"ワークベンチのリストおよびツリーのキーボード ナビゲーション スタイルを制御します。単純、強調表示、フィルターを指定できます。",
 		"リストやツリーでのキーボード ナビゲーションを、単に入力するだけで自動的にトリガーするかどうかを制御します。`false` に設定した場合、キーボード ナビゲーションは `list.toggleKeyboardNavigation` コマンドを実行したときにのみトリガーされます。これに対してキーボード ショートカットを割り当てることができます。",
+		"フォルダー名をクリックしたときにツリー フォルダーが展開される方法を制御します。適用できない場合、一部のツリーやリストではこの設定が無視されることがあります。",
 	],
 	"vs/platform/markers/common/markers": [
 		"エラー",
@@ -1038,6 +1193,7 @@ define("vs/editor/editor.main.nls.ja", {
 		"最近使用したもの",
 		"その他のコマンド",
 		"コマンド \'{0}\' でエラー ({1}) が発生しました",
+		"OK",
 	],
 	"vs/platform/quickinput/browser/helpQuickAccess": [
 		"グローバル コマンド",
@@ -1081,10 +1237,13 @@ define("vs/editor/editor.main.nls.ja", {
 		"ホバー時のスクロール バー スライダー背景色。",
 		"クリック時のスクロール バー スライダー背景色。",
 		"時間のかかる操作で表示するプログレス バーの背景色。",
+		"エディター内のエラー テキストの背景色。この色は、基本装飾が非表示にならないよう不透明にすることはできません。",
 		"エディターでエラーを示す波線の前景色。",
 		"エディター内のエラー ボックスの境界線の色です。",
+		"エディター内の警告テキストの背景色。この色は、基本装飾が非表示にならないよう不透明にすることはできません。",
 		"エディターで警告を示す波線の前景色。",
 		"エディターでの警告ボックスの境界線の色です。",
+		"エディター内の情報テキストの背景色。この色は、基本装飾が非表示にならないよう不透明にすることはできません。",
 		"エディターで情報を示す波線の前景色。",
 		"エディター内の情報ボックスの境界線の色です。",
 		"エディターでヒントを示す波線の前景色。",
@@ -1100,6 +1259,10 @@ define("vs/editor/editor.main.nls.ja", {
 		"クイック ピッカー のタイトルの背景色。クイック ピッカー ウィジェットは、コマンド パレットのようなピッカーのコンテナーです。",
 		"ラベルをグループ化するためのクリック選択の色。",
 		"境界線をグループ化するためのクイック選択の色。",
+		"キー バインド ラベルの背景色です。キー バインド ラベルはキーボード ショートカットを表すために使用されます。",
+		"キー バインド ラベルの前景色です。キー バインド ラベルはキーボード ショートカットを表すために使用されます。",
+		"キー バインド ラベルの境界線の色です。キー バインド ラベルはキーボード ショートカットを表すために使用されます。",
+		"キー バインド ラベルの下の境界線の色です。キー バインド ラベルはキーボード ショートカットを表すために使用されます。",
 		"エディターの選択範囲の色。",
 		"ハイ コントラストの選択済みテキストの色。",
 		"非アクティブなエディターの選択範囲の色。この色は、基本装飾が非表示にならないよう不透明にすることはできません。",
@@ -1117,6 +1280,8 @@ define("vs/editor/editor.main.nls.ja", {
 		"エディター ホバーの境界線の色。",
 		"エディターのホバーのステータス バーの背景色。",
 		"アクティブなリンクの色。",
+		"インライン ヒントの前景色",
+		"インライン ヒントの背景色",
 		"電球アクション アイコンに使用する色。",
 		"自動修正の電球アクション アイコンとして使用される色。",
 		"挿入されたテキストの背景色。この色は、基本装飾が非表示にならないよう不透明にすることはできません。",
@@ -1127,19 +1292,26 @@ define("vs/editor/editor.main.nls.ja", {
 		"差分エディターの対角線の塗りつぶし色。対角線の塗りつぶしは、横に並べて比較するビューで使用されます。",
 		"ツリーリストがアクティブのとき、フォーカスされた項目のツリーリスト背景色。アクティブなツリーリストはキーボード フォーカスがあり、非アクティブではこれがありません。",
 		"ツリーリストがアクティブのとき、フォーカスされた項目のツリーリスト前景色。アクティブなツリーリストはキーボード フォーカスがあり、非アクティブではこれがありません。",
+		"リストやツリーがアクティブな場合の、フォーカスされた項目のリストやツリーのアウトライン色。アクティブなリストやツリーにはキーボード フォーカスがあり、非アクティブにはこれがありません。",
 		"ツリーリストが非アクティブのとき、選択された項目のツリーリスト背景色。アクティブなツリーリストはキーボード フォーカスがあり、非アクティブではこれがありません。",
 		"ツリーリストがアクティブのとき、選択された項目のツリーリスト前景色。アクティブなツリーリストはキーボード フォーカスがあり、非アクティブではこれがありません。",
 		"ツリーリストが非アクティブのとき、選択された項目のツリーリスト背景色。アクティブなツリーリストはキーボード フォーカスがあり、非アクティブではこれがありません。",
 		"ツリーリストが非アクティブのとき、選択された項目のツリーリスト前景色。アクティブなツリーリストはキーボード フォーカスがあり、非アクティブではこれがありません。",
 		"ツリーリストが非アクティブのとき、フォーカスされた項目のツリーリスト背景色。アクティブなツリーリストはキーボード フォーカスがあり、非アクティブではこれがありません。",
+		"リストやツリーが非アクティブな場合の、フォーカスされた項目のリストやツリーのアウトライン色。アクティブなリストやツリーにはキーボード フォーカスがあり、非アクティブにはこれがありません。",
 		"マウス操作で項目をホバーするときのツリーリスト背景。",
 		"マウス操作で項目をホバーするときのツリーリスト前景。",
 		"マウス操作で項目を移動するときのツリーリスト ドラッグ アンド ドロップの背景。",
 		"ツリーリスト内を検索しているとき、一致した強調のツリーリスト前景色。",
+		"ツリー/リスト内を検索しているとき、一致した強調のツリー/リストの前景色。",
 		"リストおよびツリーの型フィルター ウェジェットの背景色。",
 		"リストおよびツリーの型フィルター ウィジェットのアウトライン色。",
 		"一致項目がない場合の、リストおよびツリーの型フィルター ウィジェットのアウトライン色。",
 		"インデント ガイドのツリー ストロークの色。",
+		"インデント ガイドのツリー ストロークの色。",
+		"代わりに quickInputList.focusBackground を使用してください",
+		"フォーカスされた項目のクイック選択の前景色。",
+		"フォーカスされた項目のクイック選択の背景色。",
 		"メニューの境界線色。",
 		"メニュー項目の前景色。",
 		"メニュー項目の背景色。",
@@ -1165,6 +1337,11 @@ define("vs/editor/editor.main.nls.ja", {
 		"問題の警告アイコンに使用される色。",
 		"問題情報アイコンに使用される色。",
 	],
+	"vs/platform/theme/common/iconRegistry": [
+		"使用するフォントの ID。設定されていない場合は、最初に定義されているフォントが使用されます。",
+		"アイコン定義に関連付けられたフォント文字。",
+		"ウィジェットにある閉じるアクションのアイコン。",
+	],
 	"vs/platform/undoRedo/common/undoRedoService": [
 		"次のファイルが閉じられ、ディスク上で変更されました: {0}。",
 		"以下のファイルは互換性のない方法で変更されました: {0}。",
@@ -1178,6 +1355,9 @@ define("vs/editor/editor.main.nls.ja", {
 		"このファイルを元に戻す",
 		"キャンセル",
 		"元に戻すまたはやり直し操作が既に実行されているため、\'{0}\' を元に戻すことはできませんでした。",
+		"\'{0}\' を元に戻しますか?",
+		"元に戻す",
+		"キャンセル",
 		"すべてのファイルで \'{0}\' をやり直しできませんでした。{1}",
 		"すべてのファイルで \'{0}\' をやり直しできませんでした。{1}",
 		"{1} に変更が加えられたため、すべてのファイルで \'{0}\' を再実行できませんでした",
