@@ -1,8 +1,8 @@
 /*!-----------------------------------------------------------
  * Copyright (c) Microsoft Corporation. All rights reserved.
- * Version: 0.21.3(b251bd952b84a3bdf68dad0141c37137dac55d64)
+ * Version: 0.25.1(336c463ee6c20d8a49e40d099b9178def0df6b18)
  * Released under the MIT license
- * https://github.com/Microsoft/vscode/blob/master/LICENSE.txt
+ * https://github.com/microsoft/vscode/blob/main/LICENSE.txt
  *-----------------------------------------------------------*/
 
 define("vs/editor/editor.main.nls.zh-cn", {
@@ -21,6 +21,9 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"输入",
 		"保留大小写",
 	],
+	"vs/base/browser/ui/iconLabel/iconLabelHover": [
+		"正在加载…",
+	],
 	"vs/base/browser/ui/inputbox/inputBox": [
 		"错误: {0}",
 		"警告: {0}",
@@ -39,6 +42,9 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"未找到元素",
 		"已匹配 {0} 个元素(共 {1} 个)",
 	],
+	"vs/base/common/actions": [
+		"(空)",
+	],
 	"vs/base/common/errorMessage": [
 		"{0}: {1}",
 		"发生了系统错误 ({0})",
@@ -71,6 +77,7 @@ define("vs/editor/editor.main.nls.zh-cn", {
 	],
 	"vs/base/parts/quickinput/browser/quickInput": [
 		"上一步",
+		"按 \"Enter\" 以确认或按 \"Esc\" 以取消",
 		"{0}/{1}",
 		"在此输入可缩小结果范围。",
 		"{0} 个结果",
@@ -86,11 +93,15 @@ define("vs/editor/editor.main.nls.zh-cn", {
 	"vs/editor/browser/controller/coreCommands": [
 		"即使转到较长的行，也一直到末尾",
 		"即使转到较长的行，也一直到末尾",
+		"已删除辅助游标",
 	],
 	"vs/editor/browser/controller/textAreaHandler": [
 		"编辑器",
 		"现在无法访问编辑器。按 {0} 获取选项。",
 	],
+	"vs/editor/browser/core/keybindingCancellation": [
+		"编辑器是否运行可取消的操作，例如“预览引用”",
+	],
 	"vs/editor/browser/editorExtensions": [
 		"撤消(&&U)",
 		"撤消",
@@ -103,9 +114,14 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"光标数量被限制为 {0}。",
 	],
 	"vs/editor/browser/widget/diffEditorWidget": [
+		"差异编辑器中插入项的线条修饰。",
+		"差异编辑器中删除项的线条修饰。",
 		"文件过大，无法比较。",
 	],
 	"vs/editor/browser/widget/diffReview": [
+		"差异评审中的“插入”图标。",
+		"差异评审中的“删除”图标。",
+		"差异评审中的“关闭”图标。",
 		"关闭",
 		"未更改行",
 		"更改了 1 行",
@@ -134,6 +150,10 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"删除自动插入的尾随空白符号。",
 		"对大型文件进行特殊处理，禁用某些内存密集型功能。",
 		"控制是否根据文档中的文字计算自动完成列表。",
+		"仅建议活动文档中的字词。",
+		"建议使用同一语言的所有打开的文档中的字词。",
+		"建议所有打开的文档中的字词。",
+		"控制通过哪些文档计算基于字词的补全。",
 		"对所有颜色主题启用语义突出显示。",
 		"对所有颜色主题禁用语义突出显示。",
 		"语义突出显示是由当前颜色主题的 \"semanticHighlighting\" 设置配置的。",
@@ -145,6 +165,9 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"启用后，差异编辑器将忽略前导空格或尾随空格中的更改。",
 		"控制差异编辑器是否为添加/删除的更改显示 +/- 指示符号。",
 		"控制是否在编辑器中显示 CodeLens。",
+		"永不换行。",
+		"将在视区宽度处换行。",
+		"将根据 `#editor.wordWrap#` 设置换行。",
 	],
 	"vs/editor/common/config/editorOptions": [
 		"编辑器将使用平台 API 以检测是否附加了屏幕阅读器。",
@@ -156,16 +179,16 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"控制在没有选择内容时进行复制是否复制当前行。",
 		"控制在键入时光标是否应跳转以查找匹配项。",
 		"控制是否将编辑器选中内容作为搜索词填入到查找小组件中。",
-		"切勿自动打开“选择中查找”(默认)",
-		"始终自动打开“在选择中查找”",
+		"切勿自动打开“在选择中查找”(默认)。",
+		"始终自动打开“在选择中查找”。",
 		"选择多行内容时，自动打开“在选择中查找”。",
 		"控制在所选内容中自动开启查找的条件。",
 		"控制“查找”小组件是否读取或修改 macOS 的共享查找剪贴板。",
 		"控制 \"查找小部件\" 是否应在编辑器顶部添加额外的行。如果为 true, 则可以在 \"查找小工具\" 可见时滚动到第一行之外。",
 		"控制在找不到其他匹配项时，是否自动从开头(或结尾)重新开始搜索。",
-		"启用或禁用字体连字。",
-		"显式字体功能设置。",
-		"配置字体连字或字体功能。",
+		"启用/禁用字体连字(\"calt\" 和 \"liga\" 字体特性)。将此更改为字符串，可对 \"font-feature-settings\" CSS 属性进行精细控制。",
+		"显式 \"font-feature-settings\" CSS 属性。如果只需打开/关闭连字，可以改为传递布尔值。",
+		"配置字体连字或字体特性。可以是用于启用/禁用连字的布尔值，或用于设置 CSS \"font-feature-settings\" 属性值的字符串。",
 		"控制字体大小(像素)。",
 		"仅允许使用关键字“正常”和“加粗”，或使用介于 1 至 1000 之间的数字。",
 		"控制字体粗细。接受关键字“正常”和“加粗”，或者接受介于 1 至 1000 之间的数字。",
@@ -187,6 +210,9 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"控制显示悬停提示前的等待时间 (毫秒)。",
 		"控制当鼠标移动到悬停提示上时，其是否保持可见。",
 		"在编辑器中启用代码操作小灯泡提示。",
+		"在编辑器中启用内联提示。",
+		"控制在编辑器中内联提示的字号。设置为 `0` 时，将使用 `#editor.fontSize#` 的 90%。",
+		"在编辑器中控制内联提示的字体系列。",
 		"控制行高。为 0 时则通过字体大小自动计算。",
 		"控制是否显示缩略图。",
 		"迷你地图的大小与编辑器内容相同(并且可能滚动)。",
@@ -214,19 +240,24 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"此编辑器标尺将渲染的等宽字符数。",
 		"此编辑器标尺的颜色。",
 		"在一定数量的等宽字符后显示垂直标尺。输入多个值，显示多个标尺。若数组为空，则不绘制标尺。",
+		"控制是否在编辑器中自动显示内联建议。",
 		"插入建议而不覆盖光标右侧的文本。",
 		"插入建议并覆盖光标右侧的文本。",
 		"控制接受补全时是否覆盖单词。请注意，这取决于扩展选择使用此功能。",
 		"控制对建议的筛选和排序是否考虑小的拼写错误。",
-		"控制排序时是否提高靠近光标的词语的优先级。",
+		"控制排序时是否首选光标附近的字词。",
 		"控制是否在多个工作区和窗口间共享记忆的建议选项(需要 `#editor.suggestSelection#`)。",
 		"控制活动代码段是否阻止快速建议。",
 		"控制是否在建议中显示或隐藏图标。",
-		"控制在显示滚动条之前 IntelliSense 将显示的建议数 (最多 15个)。",
+		"控制建议小部件底部的状态栏的可见性。",
+		"控制是否在编辑器中预览建议结果。",
+		"控制建议详细信息是随标签一起显示还是仅显示在详细信息小组件中",
+		"此设置已弃用。现在可以调整建议小组件的大小。",
 		"此设置已弃用，请改用单独的设置，如\"editor.suggest.showKeywords\"或\"editor.suggest.showSnippets\"。",
 		"启用后，IntelliSense 将显示“方法”建议。",
 		"启用后，IntelliSense 将显示“函数”建议。",
 		"启用后，IntelliSense 将显示“构造函数”建议。",
+		"启用后，IntelliSense 将显示“已启用”建议。",
 		"启用后，IntelliSense 将显示“字段”建议。",
 		"启用后，IntelliSense 将显示“变量”建议。",
 		"启用后，IntelliSense 将显示“类”建议。",
@@ -252,15 +283,17 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"启用后，IntelliSense 将显示“片段”建议。",
 		"启用后，IntelliSense 将显示\"用户\"建议。",
 		"启用后，IntelliSense 将显示\"问题\"建议。",
-		"控制建议小部件底部的状态栏的可见性。",
+		"是否应始终选择前导和尾随空格。",
 		"控制是否应在遇到提交字符时接受建议。例如，在 JavaScript 中，半角分号 (`;`) 可以为提交字符，能够在接受建议的同时键入该字符。",
 		"仅当建议包含文本改动时才可使用 `Enter` 键进行接受。",
 		"控制除了 `Tab` 键以外， `Enter` 键是否同样可以接受建议。这能减少“插入新行”和“接受建议”命令之间的歧义。",
-		"控制编辑器中可由屏幕阅读器读取的行数。警告: 对于大于默认值的数字，这会影响性能。",
+		"控制编辑器中可由屏幕阅读器一次读出的行数。我们检测到屏幕阅读器时，会自动将默认值设置为 500。警告: 如果行数大于默认值，可能会影响性能。",
 		"编辑器内容",
 		"使用语言配置确定何时自动闭合括号。",
 		"仅当光标位于空白字符左侧时，才自动闭合括号。",
 		"控制编辑器是否在左括号后自动插入右括号。",
+		"仅在自动插入时才删除相邻的右引号或右括号。",
+		"控制在删除时编辑器是否应删除相邻的右引号或右方括号。",
 		"仅在自动插入时才改写右引号或右括号。",
 		"控制编辑器是否应改写右引号或右括号。",
 		"使用语言配置确定何时自动闭合引号。",
@@ -276,7 +309,10 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"使用引号而非括号来包住所选内容。",
 		"使用括号而非引号来包住所选内容。",
 		"控制在键入引号或方括号时，编辑器是否应自动将所选内容括起来。",
+		"在使用空格进行缩进时模拟制表符的选择行为。所选内容将始终使用制表符停止位。",
 		"控制是否在编辑器中显示 CodeLens。",
+		"控制 CodeLens 的字体系列。",
+		"控制 CodeLens 的字体大小(像素)。设置为 `0` 时，将使用 `#editor.fontSize#` 的 90%。",
 		"控制编辑器是否显示内联颜色修饰器和颜色选取器。",
 		"启用使用鼠标和键进行列选择。",
 		"控制在复制时是否同时复制语法高亮。",
@@ -303,6 +339,7 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"控制是否在概览标尺中隐藏光标。",
 		"控制是否突出显示编辑器中活动的缩进参考线。",
 		"控制字母间距(像素)。",
+		"控制编辑器是否已启用链接编辑。相关符号(如 HTML 标记)在编辑时进行更新，具体由语言而定。",
 		"控制是否在编辑器中检测链接并使其可被点击。",
 		"突出显示匹配的括号。",
 		"对鼠标滚轮滚动事件的 `deltaX` 和 `deltaY` 乘上的系数。",
@@ -322,15 +359,16 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"控制\"转到定义\"鼠标手势是否始终打开预览小部件。",
 		"控制显示快速建议前的等待时间 (毫秒)。",
 		"控制是否在编辑器中输入时自动重命名。",
+		"已弃用，请改用 \"editor.linkedEditing\"。",
 		"控制编辑器是否显示控制字符。",
 		"控制编辑器是否显示缩进参考线。",
 		"当文件以换行符结束时, 呈现最后一行的行号。",
 		"同时突出显示导航线和当前行。",
 		"控制编辑器的当前行进行高亮显示的方式。",
-		"控制编辑器是否仅在焦点在编辑器时突出显示当前行",
+		"控制编辑器是否仅在焦点在编辑器时突出显示当前行。",
 		"呈现空格字符(字词之间的单个空格除外)。",
 		"仅在选定文本上呈现空白字符。",
-		"仅呈现尾随空格字符",
+		"仅呈现尾随空格字符。",
 		"控制编辑器在空白字符上显示符号的方式。",
 		"控制选区是否有圆角。",
 		"控制编辑器水平滚动时可以超过范围的字符数。",
@@ -350,7 +388,7 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"控制代码片段是否与其他建议一起显示及其排列的位置。",
 		"控制编辑器是否在滚动时使用动画。",
 		"建议小部件的字号。如果设置为 `0`，则使用 `#editor.fontSize#` 的值。",
-		"建议小部件的行高。如果设置为 `0`，则使用 `#editor.lineHeight#` 的值。",
+		"建议小部件的行高。如果设置为 `0`，则使用 `#editor.lineHeight#` 的值。最小值为 8。",
 		"控制在键入触发字符后是否自动显示建议。",
 		"始终选择第一个建议。",
 		"选择最近的建议，除非进一步键入选择其他项。例如 `console. -> console.log`，因为最近补全过 `log`。",
@@ -360,9 +398,9 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"禁用 Tab 补全。",
 		"在前缀匹配时进行 Tab 补全。在 \"quickSuggestions\" 未启用时体验最好。",
 		"启用 Tab 补全。",
+		"自动删除异常的行终止符。",
 		"忽略异常的行终止符。",
 		"提示删除异常的行终止符。",
-		"自动删除异常的行终止符。",
 		"删除可能导致问题的异常行终止符。",
 		"根据制表位插入和删除空格。",
 		"执行单词相关的导航或操作时作为单词分隔符的字符。",
@@ -381,6 +419,38 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"将包装点计算委托给浏览器。这是一个缓慢算法，可能会导致大型文件被冻结，但它在所有情况下都正常工作。",
 		"控制计算包裹点的算法。",
 	],
+	"vs/editor/common/editorContextKeys": [
+		"编辑器文本是否具有焦点(光标是否闪烁)",
+		"编辑器或编辑器小组件是否具有焦点(例如焦点在“查找”小组件中)",
+		"编辑器或 RTF 输入是否有焦点(光标是否闪烁)",
+		"编辑器是否为只读",
+		"上下文是否为差异编辑器",
+		"是否已启用 \"editor.columnSelection\"",
+		"编辑器是否已选定文本",
+		"编辑器是否有多个选择",
+		"\"Tab\" 是否将焦点移出编辑器",
+		"编辑器软键盘是否可见",
+		"该编辑器是否是更大的编辑器(例如笔记本)的一部分",
+		"编辑器的语言标识符",
+		"编辑器是否具有补全项提供程序",
+		"编辑器是否具有代码操作提供程序",
+		"编辑器是否具有 CodeLens 提供程序",
+		"编辑器是否具有定义提供程序",
+		"编辑器是否具有声明提供程序",
+		"编辑器是否具有实现提供程序",
+		"编辑器是否具有类型定义提供程序",
+		"编辑器是否具有悬停提供程序",
+		"编辑器是否具有文档突出显示提供程序",
+		"编辑器是否具有文档符号提供程序",
+		"编辑器是否具有引用提供程序",
+		"编辑器是否具有重命名提供程序",
+		"编辑器是否具有签名帮助提供程序",
+		"编辑器是否具有内联提示提供程序",
+		"编辑器是否具有文档格式设置提供程序",
+		"编辑器是否具有文档选择格式设置提供程序",
+		"编辑器是否具有多个文档格式设置提供程序",
+		"编辑器是否有多个文档选择格式设置提供程序",
+	],
 	"vs/editor/common/model/editStack": [
 		"输入",
 	],
@@ -448,6 +518,8 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"编辑器导航线的背景色。导航线包括边缘符号和行号。",
 		"编辑器中不必要(未使用)的源代码的边框颜色。",
 		"非必须(未使用)代码的在编辑器中显示的不透明度。例如，\"#000000c0\" 将以 75% 的不透明度显示代码。对于高对比度主题，请使用 ”editorUnnecessaryCode.border“ 主题来为非必须代码添加下划线，以避免颜色淡化。",
+		"编辑器中虚影文本的边框颜色。",
+		"编辑器中虚影文本的前景色。",
 		"用于突出显示范围的概述标尺标记颜色。颜色必须透明，以免隐藏下面的修饰效果。",
 		"概览标尺中错误标记的颜色。",
 		"概览标尺中警告标记的颜色。",
@@ -478,12 +550,17 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"剪切(&&T)",
 		"剪切",
 		"剪切",
+		"剪切",
 		"复制(&&C)",
 		"复制",
 		"复制",
+		"复制",
+		"复制为",
+		"复制为",
 		"粘贴(&&P)",
 		"粘贴",
 		"粘贴",
+		"粘贴",
 		"复制并突出显示语法",
 	],
 	"vs/editor/contrib/codeAction/codeActionCommands": [
@@ -540,48 +617,11 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"光标撤消",
 		"光标重做",
 	],
-	"vs/editor/contrib/documentSymbols/outlineTree": [
-		"数组符号的前景色。这些符号将显示在大纲、痕迹导航栏和建议小组件中。",
-		"布尔符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
-		"类符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
-		"颜色符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
-		"常量符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
-		"构造函数符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
-		"枚举符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
-		"枚举器成员符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
-		"事件符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
-		"字段符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
-		"文件符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
-		"文件夹符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
-		"函数符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
-		"接口符号的前景色。这些符号将显示在大纲、痕迹导航栏和建议小组件中。",
-		"键符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
-		"关键字符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
-		"方法符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
-		"模块符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
-		"命名空间符号的前景颜色。这些符号出现在轮廓、痕迹导航栏和建议小部件中。",
-		"空符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
-		"数字符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
-		"对象符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
-		"运算符符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
-		"包符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
-		"属性符号的前景色。这些符号出现在大纲、痕迹导航栏和建议小组件中。",
-		"参考符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
-		"片段符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
-		"字符串符号的前景颜色。这些符号出现在轮廓、痕迹导航栏和建议小部件中。",
-		"结构符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
-		"文本符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
-		"类型参数符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
-		"单位符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
-		"变量符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
-	],
 	"vs/editor/contrib/find/findController": [
 		"查找",
 		"查找(&&F)",
 		"查找选定内容",
 		"查找下一个",
-		"查找下一个",
-		"查找上一个",
 		"查找上一个",
 		"查找下一个选择",
 		"查找上一个选择",
@@ -589,6 +629,13 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"替换(&&R)",
 	],
 	"vs/editor/contrib/find/findWidget": [
+		"编辑器查找小组件中的“在选定内容中查找”图标。",
+		"用于指示编辑器查找小组件已折叠的图标。",
+		"用于指示编辑器查找小组件已展开的图标。",
+		"编辑器查找小组件中的“替换”图标。",
+		"编辑器查找小组件中的“全部替换”图标。",
+		"编辑器查找小组件中的“查找上一个”图标。",
+		"编辑器查找小组件中的“查找下一个”图标。",
 		"查找",
 		"查找",
 		"上一个匹配项",
@@ -618,12 +665,18 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"折叠所有块注释",
 		"折叠所有区域",
 		"展开所有区域",
+		"折叠除所选区域之外的所有区域",
+		"展开除所选区域之外的所有区域",
 		"全部折叠",
 		"全部展开",
 		"折叠级别 {0}",
 		"折叠范围后面的背景颜色。颜色必须设为透明，以免隐藏底层装饰。",
 		"编辑器装订线中折叠控件的颜色。",
 	],
+	"vs/editor/contrib/folding/foldingDecorations": [
+		"编辑器字形边距中已展开的范围的图标。",
+		"编辑器字形边距中已折叠的范围的图标。",
+	],
 	"vs/editor/contrib/fontZoom/fontZoom": [
 		"放大编辑器字体",
 		"缩小编辑器字体",
@@ -641,7 +694,9 @@ define("vs/editor/editor.main.nls.zh-cn", {
 	],
 	"vs/editor/contrib/gotoError/gotoError": [
 		"转到下一个问题 (错误、警告、信息)",
+		"“转到下一个”标记的图标。",
 		"转到上一个问题 (错误、警告、信息)",
+		"“转到上一个”标记的图标。",
 		"转到文件中的下一个问题 (错误、警告、信息)",
 		"下一个问题(&&P)",
 		"转到文件中的上一个问题 (错误、警告、信息)",
@@ -705,6 +760,7 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"单击显示 {0} 个定义。",
 	],
 	"vs/editor/contrib/gotoSymbol/peek/referencesController": [
+		"引用速览是否可见，例如“速览引用”或“速览定义”",
 		"正在加载...",
 		"{0} ({1})",
 	],
@@ -720,6 +776,7 @@ define("vs/editor/editor.main.nls.zh-cn", {
 	],
 	"vs/editor/contrib/gotoSymbol/referencesModel": [
 		"在文件 {0} 的 {1} 行 {2} 列的符号",
+		"{0} 中 {1} 行 {2} 列的符号，{3}",
 		"{0} 中有 1 个符号，完整路径: {1}",
 		"{1} 中有 {0} 个符号，完整路径: {2}",
 		"未找到结果",
@@ -728,6 +785,7 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"在 {1} 个文件中找到 {0} 个符号",
 	],
 	"vs/editor/contrib/gotoSymbol/symbolNavigation": [
+		"是否存在只能通过键盘导航的符号位置。",
 		"{1} 的符号 {0}，下一个使用 {2}",
 		"{1} 的符号 {0}",
 	],
@@ -735,9 +793,12 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"显示悬停",
 		"显示定义预览悬停",
 	],
-	"vs/editor/contrib/hover/modesContentHover": [
+	"vs/editor/contrib/hover/markdownHoverParticipant": [
 		"正在加载...",
-		"速览问题",
+	],
+	"vs/editor/contrib/hover/markerHoverParticipant": [
+		"查看问题",
+		"没有可用的快速修复",
 		"正在检查快速修复...",
 		"没有可用的快速修复",
 		"快速修复...",
@@ -757,6 +818,18 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"重新缩进行",
 		"重新缩进所选行",
 	],
+	"vs/editor/contrib/inlineCompletions/ghostTextController": [
+		"内联建议是否可见",
+		"内联建议是否以空白开头",
+		"显示下一个内联建议",
+		"显示上一个内联建议",
+		"触发内联建议",
+	],
+	"vs/editor/contrib/inlineCompletions/inlineCompletionsHoverParticipant": [
+		"下一个",
+		"上一个",
+		"接受",
+	],
 	"vs/editor/contrib/linesOperations/linesOperations": [
 		"向上复制行",
 		"向上复制行(&&C)",
@@ -783,6 +856,11 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"转换为大写",
 		"转换为小写",
 		"转换为词首字母大写",
+		"转换为蛇形命名法",
+	],
+	"vs/editor/contrib/linkedEditing/linkedEditing": [
+		"启动链接编辑",
+		"编辑器根据类型自动重命名时的背景色。",
 	],
 	"vs/editor/contrib/links/links": [
 		"执行命令",
@@ -791,14 +869,18 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"ctrl + 单击",
 		"option + 单击",
 		"alt + 单击",
+		"执行命令 {0}",
 		"此链接格式不正确，无法打开: {0}",
 		"此链接目标已丢失，无法打开。",
 		"打开链接",
 	],
 	"vs/editor/contrib/message/messageController": [
+		"编辑器当前是否正在显示内联消息",
 		"无法在只读编辑器中编辑",
 	],
 	"vs/editor/contrib/multicursor/multicursor": [
+		"添加的光标: {0}",
+		"添加的游标: {0}",
 		"在上面添加光标",
 		"在上面添加光标(&&A)",
 		"在下面添加光标",
@@ -821,9 +903,12 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"触发参数提示",
 	],
 	"vs/editor/contrib/parameterHints/parameterHintsWidget": [
+		"“显示下一个参数”提示的图标。",
+		"“显示上一个参数”提示的图标。",
 		"{0}，提示",
 	],
 	"vs/editor/contrib/peekView/peekView": [
+		"速览中是否嵌入了当前代码编辑器",
 		"关闭",
 		"速览视图标题区域背景颜色。",
 		"速览视图标题颜色。",
@@ -842,7 +927,7 @@ define("vs/editor/editor.main.nls.zh-cn", {
 	],
 	"vs/editor/contrib/quickAccess/gotoLineQuickAccess": [
 		"先打开文本编辑器然后跳转到行。",
-		"转到第 {0} 行、第 {1} 列。",
+		"转到第 {0} 行第 {1} 个字符。",
 		"转到行 {0}。",
 		"当前行: {0}，字符: {1}。键入要导航到的行号(介于 1 至 {2} 之间)。",
 		"当前行: {0}，字符: {1}。 键入要导航到的行号。",
@@ -882,10 +967,6 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"字段({0})",
 		"常量({0})",
 	],
-	"vs/editor/contrib/rename/onTypeRename": [
-		"在键入时重命名符号",
-		"编辑器根据类型自动重命名时的背景色。",
-	],
 	"vs/editor/contrib/rename/rename": [
 		"无结果。",
 		"解析重命名位置时发生未知错误",
@@ -898,6 +979,7 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"启用/禁用重命名之前预览更改的功能",
 	],
 	"vs/editor/contrib/rename/renameInputField": [
+		"重命名输入小组件是否可见",
 		"重命名输入。键入新名称并按 \"Enter\" 提交。",
 		"按 {0} 进行重命名，按 {1} 进行预览",
 	],
@@ -907,6 +989,11 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"收起选择",
 		"缩小选定范围(&&S)",
 	],
+	"vs/editor/contrib/snippet/snippetController2": [
+		"编辑器目前是否在代码片段模式下",
+		"在代码片段模式下时是否存在下一制表位",
+		"在代码片段模式下时是否存在上一制表位",
+	],
 	"vs/editor/contrib/snippet/snippetVariables": [
 		"星期天",
 		"星期一",
@@ -947,31 +1034,87 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"11 月",
 		"12月",
 	],
+	"vs/editor/contrib/suggest/suggest": [
+		"建议是否可见",
+		"建议详细信息是否可见",
+		"是否存在多条建议可供选择",
+		"插入当前建议是否会导致更改或导致已键入所有内容",
+		"按 Enter 时是否会插入建议",
+		"当前建议是否具有插入和替换行为",
+		"默认行为是否是插入或替换",
+		"当前建议是否支持解析更多详细信息",
+	],
 	"vs/editor/contrib/suggest/suggestController": [
-		"Accepting \'{0}\' made {1} additional edits",
+		"选择“{0}”后进行了其他 {1} 次编辑",
 		"触发建议",
-		"{0} 插入",
-		"{0} 插入",
-		"{0} 替换",
-		"{0} 替换",
-		"{0} 插入",
+		"插入",
+		"插入",
+		"替换",
+		"替换",
+		"插入",
 		"显示更少",
 		"显示更多",
+		"重置建议小组件大小",
 	],
 	"vs/editor/contrib/suggest/suggestWidget": [
 		"建议小组件的背景色。",
 		"建议小组件的边框颜色。",
 		"建议小组件的前景色。",
+		"建议小组件中所选条目的前景色。",
 		"建议小组件中所选条目的背景色。",
 		"建议小组件中匹配内容的高亮颜色。",
-		"读取更多({0})",
-		"读取更少({0})",
-		"正在加载...",
+		"当某项获得焦点时，在建议小组件中突出显示的匹配项的颜色。",
 		"正在加载...",
 		"无建议。",
 		"{0}，文档: {1}",
 		"建议",
 	],
+	"vs/editor/contrib/suggest/suggestWidgetDetails": [
+		"关闭",
+		"正在加载…",
+	],
+	"vs/editor/contrib/suggest/suggestWidgetRenderer": [
+		"建议小组件中的详细信息的图标。",
+		"了解详细信息",
+	],
+	"vs/editor/contrib/suggest/suggestWidgetStatus": [
+		"{0} ({1})",
+	],
+	"vs/editor/contrib/symbolIcons/symbolIcons": [
+		"数组符号的前景色。这些符号将显示在大纲、痕迹导航栏和建议小组件中。",
+		"布尔符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
+		"类符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
+		"颜色符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
+		"常量符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
+		"构造函数符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
+		"枚举符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
+		"枚举器成员符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
+		"事件符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
+		"字段符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
+		"文件符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
+		"文件夹符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
+		"函数符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
+		"接口符号的前景色。这些符号将显示在大纲、痕迹导航栏和建议小组件中。",
+		"键符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
+		"关键字符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
+		"方法符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
+		"模块符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
+		"命名空间符号的前景颜色。这些符号出现在轮廓、痕迹导航栏和建议小部件中。",
+		"空符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
+		"数字符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
+		"对象符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
+		"运算符符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
+		"包符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
+		"属性符号的前景色。这些符号出现在大纲、痕迹导航栏和建议小组件中。",
+		"参考符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
+		"片段符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
+		"字符串符号的前景颜色。这些符号出现在轮廓、痕迹导航栏和建议小部件中。",
+		"结构符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
+		"文本符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
+		"类型参数符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
+		"单位符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
+		"变量符号的前景颜色。这些符号出现在大纲、痕迹导航栏和建议小部件中。",
+	],
 	"vs/editor/contrib/toggleTabFocusMode/toggleTabFocusMode": [
 		"切换 Tab 键移动焦点",
 		"Tab 键将移动到下一可聚焦的元素",
@@ -998,16 +1141,27 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"转到上一个突出显示的符号",
 		"触发符号高亮",
 	],
+	"vs/editor/contrib/wordOperations/wordOperations": [
+		"删除 Word",
+	],
 	"vs/platform/actions/browser/menuEntryActionViewItem": [
 		"{0} ({1})",
+		"{0} ({1})",
 	],
 	"vs/platform/configuration/common/configurationRegistry": [
 		"默认语言配置替代",
 		"针对某种语言，配置替代编辑器设置。",
 		"此设置不支持按语言配置。",
+		"无法注册空属性",
 		"无法注册“{0}”。其符合描述特定语言编辑器设置的表达式 \"\\\\[.*\\\\]$\"。请使用 \"configurationDefaults\"。",
 		"无法注册“{0}”。此属性已注册。",
 	],
+	"vs/platform/contextkey/browser/contextKeyService": [
+		"用于返回上下文键的相关信息的命令",
+	],
+	"vs/platform/contextkey/common/contextkeys": [
+		"操作系统是否为 Windows",
+	],
 	"vs/platform/keybinding/common/abstractKeybindingService": [
 		"({0})已按下。正在等待按下第二个键...",
 		"组合键({0}，{1})不是命令。",
@@ -1017,7 +1171,7 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"映射为 `Ctrl` (Windows 和 Linux) 或 `Command` (macOS)。",
 		"映射为 `Alt` (Windows 和 Linux) 或 `Option` (macOS)。",
 		"在通过鼠标多选树和列表条目时使用的修改键 (例如“资源管理器”、“打开的编辑器”和“源代码管理”视图)。“在侧边打开”功能所需的鼠标动作 (若可用) 将会相应调整，不与多选修改键冲突。",
-		"控制在树和列表中怎样使用鼠标来展开子项(若支持)。对于树中的父节点，此设置将控制是使用单击还是双击来展开。注意，某些不适用于此设置的树或列表可能会忽略此项。 ",
+		"控制如何使用鼠标打开树和列表中的项(若支持)。请注意，如果此设置不适用，某些树和列表可能会选择忽略它。",
 		"控制列表和树是否支持工作台中的水平滚动。警告: 打开此设置影响会影响性能。",
 		"控制树缩进(以像素为单位)。",
 		"控制树是否应呈现缩进参考线。",
@@ -1027,6 +1181,7 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"筛选器键盘导航将筛选出并隐藏与键盘输入不匹配的所有元素。",
 		"控制工作台中的列表和树的键盘导航样式。它可为“简单”、“突出显示”或“筛选”。",
 		"控制列表和树中的键盘导航是否仅通过键入自动触发。如果设置为 `false` ，键盘导航只在执行 `list.toggleKeyboardNavigation` 命令时触发，您可以为该命令指定键盘快捷方式。",
+		"控制在单击文件夹名称时如何扩展树文件夹。请注意，如果不适用，某些树和列表可能会选择忽略此设置。",
 	],
 	"vs/platform/markers/common/markers": [
 		"错误",
@@ -1038,6 +1193,7 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"最近使用",
 		"其他命令",
 		"命令\"{0}\"导致错误 ({1})",
+		"确定",
 	],
 	"vs/platform/quickinput/browser/helpQuickAccess": [
 		"全局命令",
@@ -1081,10 +1237,13 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"滚动条滑块在悬停时的背景色",
 		"滚动条滑块在被点击时的背景色。",
 		"表示长时间操作的进度条的背景色。",
+		"编辑器中错误文本的背景色。颜色必须透明，以免隐藏下面的修饰效果。",
 		"编辑器中错误波浪线的前景色。",
 		"编辑器中错误框的边框颜色。",
+		"编辑器中警告文本的背景色。颜色必须透明，以免隐藏下面的修饰效果。",
 		"编辑器中警告波浪线的前景色。",
 		"编辑器中警告框的边框颜色。",
+		"编辑器中信息文本的背景色。颜色必须透明，以免隐藏下面的修饰效果。",
 		"编辑器中信息波浪线的前景色。",
 		"编辑器中信息框的边框颜色。",
 		"编辑器中提示波浪线的前景色。",
@@ -1100,6 +1259,10 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"标题背景颜色快速选取器。快速选取器小部件是命令调色板等选取器的容器。",
 		"快速选取器分组标签的颜色。",
 		"快速选取器分组边框的颜色。",
+		"键绑定标签背景色。键绑定标签用于表示键盘快捷方式。",
+		"键绑定标签前景色。键绑定标签用于表示键盘快捷方式。",
+		"键绑定标签边框色。键绑定标签用于表示键盘快捷方式。",
+		"键绑定标签边框底部色。键绑定标签用于表示键盘快捷方式。",
 		"编辑器所选内容的颜色。",
 		"用以彰显高对比度的所选文本的颜色。",
 		"非活动编辑器中所选内容的颜色，颜色必须透明，以免隐藏下面的装饰效果。",
@@ -1117,6 +1280,8 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"光标悬停时编辑器的边框颜色。",
 		"编辑器悬停状态栏的背景色。",
 		"活动链接颜色。",
+		"内联提示的前景色",
+		"内联提示的背景色",
 		"用于灯泡操作图标的颜色。",
 		"用于灯泡自动修复操作图标的颜色。",
 		"已插入的文本的背景色。颜色必须透明，以免隐藏下面的修饰效果。",
@@ -1127,19 +1292,26 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"差异编辑器的对角线填充颜色。对角线填充用于并排差异视图。",
 		"焦点项在列表或树活动时的背景颜色。活动的列表或树具有键盘焦点，非活动的没有。",
 		"焦点项在列表或树活动时的前景颜色。活动的列表或树具有键盘焦点，非活动的没有。",
+		"列表/树活动时，焦点项目的列表/树边框色。活动的列表/树具有键盘焦点，非活动的没有。",
 		"已选项在列表或树活动时的背景颜色。活动的列表或树具有键盘焦点，非活动的没有。",
 		"已选项在列表或树活动时的前景颜色。活动的列表或树具有键盘焦点，非活动的没有。",
 		"已选项在列表或树非活动时的背景颜色。活动的列表或树具有键盘焦点，非活动的没有。",
 		"已选项在列表或树非活动时的前景颜色。活动的列表或树具有键盘焦点，非活动的没有。",
 		"非活动的列表或树控件中焦点项的背景颜色。活动的列表或树具有键盘焦点，非活动的没有。",
+		"列表/数非活动时，焦点项目的列表/树边框色。活动的列表/树具有键盘焦点，非活动的没有。",
 		"使用鼠标移动项目时，列表或树的背景颜色。",
 		"鼠标在项目上悬停时，列表或树的前景颜色。",
 		"使用鼠标移动项目时，列表或树进行拖放的背景颜色。",
 		"在列表或树中搜索时，其中匹配内容的高亮颜色。",
+		"在列表或树中搜索时，匹配活动聚焦项的突出显示内容的列表/树前景色。",
 		"列表和树中类型筛选器小组件的背景色。",
 		"列表和树中类型筛选器小组件的轮廓颜色。",
 		"当没有匹配项时，列表和树中类型筛选器小组件的轮廓颜色。",
 		"缩进参考线的树描边颜色。",
+		"缩进参考线的树描边颜色。",
+		"请改用 quickInputList.focusBackground",
+		"焦点项目的快速选择器前景色。",
+		"焦点项目的快速选择器背景色。",
 		"菜单的边框颜色。",
 		"菜单项的前景颜色。",
 		"菜单项的背景颜色。",
@@ -1165,6 +1337,11 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"用于问题警告图标的颜色。",
 		"用于问题信息图标的颜色。",
 	],
+	"vs/platform/theme/common/iconRegistry": [
+		"要使用的字体的 ID。如果未设置，则使用最先定义的字体。",
+		"与图标定义关联的字体字符。",
+		"小组件中“关闭”操作的图标。",
+	],
 	"vs/platform/undoRedo/common/undoRedoService": [
 		"以下文件已关闭并且已在磁盘上修改: {0}。",
 		"以下文件已以不兼容的方式修改: {0}。",
@@ -1178,6 +1355,9 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"撤消此文件",
 		"取消",
 		"无法撤销“{0}”，因为已有一项撤消或重做操作正在运行。",
+		"是否要撤消“{0}”?",
+		"撤消",
+		"取消",
 		"无法在所有文件中重做“{0}”。{1}",
 		"无法在所有文件中重做“{0}”。{1}",
 		"无法对所有文件重做“{0}”，因为已更改 {1}",
