@@ -1,8 +1,8 @@
 /*!-----------------------------------------------------------
  * Copyright (c) Microsoft Corporation. All rights reserved.
- * Version: 0.21.3(b251bd952b84a3bdf68dad0141c37137dac55d64)
+ * Version: 0.25.1(336c463ee6c20d8a49e40d099b9178def0df6b18)
  * Released under the MIT license
- * https://github.com/Microsoft/vscode/blob/master/LICENSE.txt
+ * https://github.com/microsoft/vscode/blob/main/LICENSE.txt
  *-----------------------------------------------------------*/
 
 define("vs/editor/editor.main.nls.zh-tw", {
@@ -21,6 +21,9 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"輸入",
 		"保留案例",
 	],
+	"vs/base/browser/ui/iconLabel/iconLabelHover": [
+		"正在載入...",
+	],
 	"vs/base/browser/ui/inputbox/inputBox": [
 		"錯誤: {0}",
 		"警告: {0}",
@@ -39,6 +42,9 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"找不到任何元素",
 		"{1} 項元素中有 {0} 項相符",
 	],
+	"vs/base/common/actions": [
+		"(空的)",
+	],
 	"vs/base/common/errorMessage": [
 		"{0}: {1}",
 		"發生系統錯誤 ({0})",
@@ -71,6 +77,7 @@ define("vs/editor/editor.main.nls.zh-tw", {
 	],
 	"vs/base/parts/quickinput/browser/quickInput": [
 		"上一頁",
+		"按 \'Enter\' 鍵確認您的輸入或按 \'Esc\' 鍵取消",
 		"{0}/{1}",
 		"輸入以縮小結果範圍。",
 		"{0} 個結果",
@@ -86,11 +93,15 @@ define("vs/editor/editor.main.nls.zh-tw", {
 	"vs/editor/browser/controller/coreCommands": [
 		"即使行的長度過長，仍要堅持至結尾",
 		"即使行的長度過長，仍要堅持至結尾",
+		"已移除次要資料指標",
 	],
 	"vs/editor/browser/controller/textAreaHandler": [
 		"編輯器",
 		"目前無法存取此編輯器。請按 {0} 取得選項。",
 	],
+	"vs/editor/browser/core/keybindingCancellation": [
+		"編輯器是否執行可取消的作業，例如「預覽參考」",
+	],
 	"vs/editor/browser/editorExtensions": [
 		"復原(&&U)",
 		"復原",
@@ -103,9 +114,14 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"游標數已限制為 {0} 個。",
 	],
 	"vs/editor/browser/widget/diffEditorWidget": [
+		"Diff 編輯器中用於插入的線條裝飾。",
+		"Diff 編輯器中用於移除的線條裝飾。",
 		"因其中一個檔案過大而無法比較。",
 	],
 	"vs/editor/browser/widget/diffReview": [
+		"Diff 檢閱中 [插入] 的圖示。",
+		"Diff 檢閱中 [移除] 的圖示。",
+		"Diff 檢閱中 [關閉] 的圖示。",
 		"關閉",
 		"未變更任一行",
 		"已變更 1 行",
@@ -134,6 +150,10 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"移除尾端自動插入的空白字元。",
 		"針對大型檔案停用部分高記憶體需求功能的特殊處理方式。",
 		"控制是否應根據文件中的單字計算自動完成。",
+		"僅建議來自使用中文件中的字組。",
+		"建議來自所有已開啟文件中，語言相同的字組。",
+		"建議來自所有已開啟文件中的字組。",
+		"控制要從哪些文件計算以字組為基礎的完成作業。",
 		"所有彩色主題皆已啟用語意醒目提示。",
 		"所有彩色主題皆已停用語意醒目提示。",
 		"語意醒目提示由目前之彩色佈景主題的 \'semanticHighlighting\' 設定所設定。",
@@ -145,6 +165,9 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"啟用時，Diff 編輯器會忽略前置或後置空格的變更。",
 		"控制 Diff 編輯器是否要為新增/移除的變更顯示 +/- 標記。",
 		"控制編輯器是否顯示 codelens。",
+		"一律不換行。",
+		"依檢視區寬度換行。",
+		"將依據 `#editor.wordWrap#` 設定自動換行。",
 	],
 	"vs/editor/common/config/editorOptions": [
 		"編輯器將使用平台 API 以偵測螢幕助讀程式附加。",
@@ -156,16 +179,16 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"控制複製時不選取任何項目是否會複製目前程式行。",
 		"控制在輸入期間是否要跳過游標來尋找相符的項目。",
 		"控制 [尋找小工具] 中的搜尋字串是否來自編輯器選取項目。",
-		"永不自動開啟 [在選取範圍中尋找] (預設)",
-		"一律自動開啟 [在選取範圍中尋找]",
+		"永不自動開啟 [在選取範圍中尋找] (預設)。",
+		"一律自動開啟 [在選取範圍中尋找]。",
 		"選取多行內容時，自動開啟 [在選取範圍中尋找]。",
 		"控制自動開啟在選取範圍中尋找的條件。",
 		"控制尋找小工具是否在 macOS 上讀取或修改共用尋找剪貼簿。",
 		"控制尋找小工具是否應在編輯器頂端額外新增行。若為 true，當您可看到尋找小工具時，您的捲動範圍會超過第一行。",
 		"當再也找不到其他相符項目時，控制是否自動從開頭 (或結尾) 重新開始搜尋。",
-		"啟用/停用連字字型。",
-		"明確 font-feature-settings。",
-		"設定連字字型或字型功能。",
+		"啟用/停用連字字型 (\'calt\' 和 \'liga\' 字型功能)。將此項變更為字串，以精確控制 \'font-feature-settings\' CSS 屬性。",
+		"明確的 \'font-feature-settings\' CSS 屬性。如果只需要開啟/關閉連字，可以改為傳遞布林值。",
+		"設定連字字型或字型功能。可以是布林值以啟用/停用連字，或代表 CSS \'font-feature-settings\' 屬性的字串。",
 		"控制字型大小 (像素)。",
 		"只允許「一般」及「粗體」關鍵字，或介於 1 到 1000 之間的數值。",
 		"控制字型粗細。接受「一般」及「粗體」關鍵字，或介於 1 到 1000 之間的數值。",
@@ -187,6 +210,9 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"控制暫留顯示的延遲時間 (以毫秒為單位)。",
 		"控制當滑鼠移過時，是否應保持顯示暫留。",
 		"在編輯器中啟用程式碼動作燈泡。",
+		"啟用編輯器中的內嵌提示。",
+		"控制編輯器中的內嵌提示字型大小。設定為 `0` 時，會使用 90% 的 `#editor.fontSize#`。",
+		"控制編輯器中的內嵌提示字型家族。",
 		"控制行高。使用 0 會從字型大小計算行高。",
 		"控制是否會顯示縮圖",
 		"縮圖大小與編輯器內容相同 (且可能會捲動)。",
@@ -214,19 +240,24 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"這個編輯器尺規會轉譯的等寬字元數。",
 		"此編輯器尺規的色彩。",
 		"在某個數目的等寬字元之後顯示垂直尺規。如有多個尺規，就會使用多個值。若陣列空白，就不會繪製任何尺規。",
+		"控制是否要在編輯器中自動顯示內嵌建議。",
 		"插入建議而不覆寫游標旁的文字。",
 		"插入建議並覆寫游標旁的文字。",
 		"控制是否要在接受完成時覆寫字組。請注意，這取決於加入此功能的延伸模組。",
 		"控制對於拚錯字是否進行篩選和排序其建議",
-		"控制排序是否會偏好游標附近出現的字組。",
+		"控制排序是否偏好游標附近的字組。",
 		"控制記錄的建議選取項目是否在多個工作區和視窗間共用 (需要 `#editor.suggestSelection#`)。",
 		"控制正在使用的程式碼片段是否會避免快速建議。",
 		"控制要在建議中顯示或隱藏圖示。",
-		"控制 IntelliSense 顯示捲軸前要顯示多少建議 (最多 15 個)。",
+		"控制建議小工具底下的狀態列可見度。",
+		"控制是否要在編輯器中預覽建議結果。",
+		"控制建議詳細資料是以內嵌於標籤的方式顯示，還是只在詳細資料小工具中顯示",
+		"此設定已淘汰。建議小工具現可調整大小。",
 		"此設定已淘汰，請改用 \'editor.suggest.showKeywords\' 或 \'editor.suggest.showSnippets\' 等單獨設定。",
 		"啟用時，IntelliSense 顯示「方法」建議。",
 		"啟用時，IntelliSense 顯示「函式」建議。",
 		"啟用時，IntelliSense 顯示「建構函式」建議。",
+		"啟用時，IntelliSense 顯示「已取代」建議。",
 		"啟用時，IntelliSense 顯示「欄位」建議。",
 		"啟用時，IntelliSense 顯示「變數」建議。",
 		"啟用時，IntelliSense 顯示「類別」建議。",
@@ -252,15 +283,17 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"啟用時，IntelliSense 顯示「程式碼片段」建議。",
 		"啟用之後，IntelliSense 會顯示 `user`-suggestions。",
 		"啟用時，IntelliSense 會顯示 `issues`-suggestions。",
-		"控制建議小工具底下的狀態列可見度。",
+		"是否應一律選取前置和後置的空白字元。",
 		"控制是否透過認可字元接受建議。例如在 JavaScript 中，分號 (\';\') 可以是接受建議並鍵入該字元的認可字元。",
 		"在建議進行文字變更時，僅透過 `Enter` 接受建議。",
 		"控制除了 \'Tab\' 外，是否也透過 \'Enter\' 接受建議。這有助於避免混淆要插入新行或接受建議。",
-		"控制編輯器中螢幕助讀程式可讀出的行數。警告: 大於預設的數目會對效能產生影響。",
+		"控制編輯器中可一次由螢幕助讀程式讀出的行數。偵測到螢幕助讀程式時會自動預設為 500。警告: 若數字超過預設，可能會對效能有所影響。",
 		"編輯器內容",
 		"使用語言配置確定何時自動關閉括號。",
 		"僅當游標位於空白的左側時自動關閉括號。",
 		"控制編輯器是否應在使用者新增左括弧後，自動加上右括弧。",
+		"僅在自動插入相鄰的右引號或括弧時，才將其移除。",
+		"控制編輯器是否應在刪除時移除相鄰的右引號或括弧。",
 		"僅在自動插入右引號或括號時，才在其上方鍵入。",
 		"控制編輯器是否應在右引號或括號上鍵入。",
 		"使用語言配置確定何時自動關閉引號。",
@@ -276,7 +309,10 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"用引號括住，而非使用括弧。",
 		"用括弧括住，而非使用引號。 ",
 		"控制編輯器是否應在鍵入引號或括弧時自動包圍選取範圍。",
+		"當使用空格進行縮排時，會模擬定位字元的選取表現方式。選取範圍會依循定位停駐點。",
 		"控制編輯器是否顯示 codelens。",
+		"控制 CodeLens 的字型家族。",
+		"控制 CodeLens 的字型大小 (像素)。設定為 `0` 時，會使用 90% 的 `#editor.fontSize#`。",
 		"控制編輯器是否應轉譯內嵌色彩裝飾項目與色彩選擇器。",
 		"啟用即可以滑鼠與按鍵選取進行資料行選取。",
 		"控制語法醒目提示是否應複製到剪貼簿。",
@@ -303,6 +339,7 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"控制游標是否應隱藏在概觀尺規中。",
 		"控制編輯器是否應醒目提示使用中的縮排輔助線。",
 		"控制字母間距 (像素)。",
+		"控制編輯器是否已啟用連結編輯。相關符號 (例如 HTML 標籤) 會根據語言在編輯時更新。",
 		"控制編輯器是否應偵測連結並使其可供點選。",
 		"將符合的括號醒目提示。",
 		"要用於滑鼠滾輪捲動事件 `deltaX` 和 `deltaY` 的乘數。",
@@ -322,15 +359,16 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"控制「前往定義」滑鼠手勢，是否一律開啟瞄核小工具。",
 		"控制在快速建議顯示後的延遲 (以毫秒為單位)。",
 		"控制編輯器是否會自動依類型重新命名。",
+		"已淘汰，請改用 `editor.linkedEditing`。",
 		"控制編輯器是否應顯示控制字元。",
 		"控制編輯器是否應顯示縮排輔助線。",
 		"在檔案結尾為新行時，呈現最後一行的號碼。",
 		"醒目提示裝訂邊和目前的行。",
 		"控制編輯器如何顯示目前行的醒目提示。",
-		"當焦點為該編輯器時，控制該編輯器是否僅應轉譯目前行的醒目提示",
+		"控制當聚焦於編輯器時，編輯器是否應僅轉譯目前行的醒目提示。",
 		"轉譯空白字元，但文字之間的單一空格除外。",
 		"只轉譯所選文字的空白字元。",
-		"只轉譯結尾空白字元",
+		"只轉譯結尾空白字元。",
 		"控制編輯器應如何轉譯空白字元。",
 		"控制選取範圍是否有圓角",
 		"控制編輯器水平捲動的額外字元數。",
@@ -350,7 +388,7 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"控制程式碼片段是否隨其他建議顯示，以及其排序方式。",
 		"控制編輯器是否會使用動畫捲動",
 		"建議小工具的字型大小。當設定為 `0` 時，則使用 `#editor.fontSize#` 值.",
-		"建議小工具的行高。當設定為 `0` 時，則使用 `#editor.lineHeight#` 值.",
+		"建議小工具的行高。當設定為 `0` 時，則使用 `#editor.lineHeight#` 的值。最小值為 8。",
 		"控制建議是否應在鍵入觸發字元時自動顯示。",
 		"一律選取第一個建議。",
 		"除非進一步鍵入選取了建議，否則選取最近的建議，例如 `console.| -> console.log`，原因是最近完成了 `log`。",
@@ -360,9 +398,9 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"停用 tab 鍵自動完成。",
 		"在程式碼片段的首碼相符時使用 Tab 完成。未啟用 \'quickSuggestions\' 時效果最佳。",
 		"啟用 tab 鍵自動完成。",
+		"自動移除異常的行結束字元。",
 		"忽略異常的行結束字元。",
 		"要移除之異常的行結束字元提示。",
-		"自動移除異常的行結束字元。",
 		"移除可能導致問題的異常行結束字元。",
 		"插入和刪除接在定位停駐點後的空白字元。",
 		"在執行文字相關導覽或作業時要用作文字分隔符號的字元",
@@ -381,6 +419,38 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"將外圍點計算委派給瀏覽器。這是緩慢的演算法，如果檔案較大可能會導致凍結，但在所有情況下都正常運作。",
 		"控制計算外圍點的演算法。",
 	],
+	"vs/editor/common/editorContextKeys": [
+		"編輯器文字是否有焦點 (游標閃爍)",
+		"編輯器或編輯器小工具是否有焦點 (例如焦點位於 [尋找] 小工具中)",
+		"編輯器或 RTF 輸入是否有焦點 (游標閃爍)",
+		"編輯器是否為唯讀",
+		"內容是否為 Diff 編輯器",
+		"\'editor.columnSelection\' 是否已啟用",
+		"編輯器是否有選取文字",
+		"編輯器是否有多個選取項目",
+		"\'Tab\' 是否會將焦點移出編輯器",
+		"編輯器暫留是否顯示",
+		"編輯器是否為較大編輯器的一部分 (例如筆記本)",
+		"編輯器的語言識別碼",
+		"編輯器是否有完成項目提供者",
+		"編輯器是否有程式碼動作提供者",
+		"編輯器是否有 CodeLens 提供者",
+		"編輯器是否有定義提供者",
+		"編輯器是否有宣告提供者",
+		"編輯器是否有實作提供者",
+		"編輯器是否有型別定義提供者",
+		"編輯器是否有暫留提供者",
+		"編輯器是否有文件醒目提示提供者",
+		"編輯器是否有文件符號提供者",
+		"編輯器是否有參考提供者",
+		"編輯器是否有重新命名提供者",
+		"編輯器是否有簽章說明提供者",
+		"編輯器是否有內嵌提示提供者",
+		"編輯器是否有文件格式化提供者",
+		"編輯器是否有文件選取項目格式化提供者",
+		"編輯器是否有多個文件格式化提供者",
+		"編輯器是否有多個文件選取項目格式化提供者",
+	],
 	"vs/editor/common/model/editStack": [
 		"正在鍵入",
 	],
@@ -448,6 +518,8 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"編輯器邊框的背景顏色,包含行號與字形圖示的邊框.",
 		"編輯器中不必要 (未使用) 原始程式碼的框線色彩。",
 		"編輯器中不必要 (未使用) 原始程式碼的不透明度。例如 \"#000000c0” 會以 75% 的不透明度轉譯程式碼。針對高對比主題，使用 \'editorUnnecessaryCode.border\' 主題色彩可為不必要的程式碼加上底線，而不是將其變淡。",
+		"編輯器中浮水印文字的邊框色彩。",
+		"編輯器中浮水印文字的前景色彩。",
 		"範圍醒目提示的概觀尺規標記色彩。其不得為不透明色彩，以免隱藏底層裝飾。",
 		"錯誤的概觀尺規標記色彩。",
 		"警示的概觀尺規標記色彩。",
@@ -478,12 +550,17 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"剪下(&&T)",
 		"剪下",
 		"剪下",
+		"剪下",
 		"複製(&&C)",
 		"複製",
 		"複製",
+		"複製",
+		"複製為",
+		"複製為",
 		"貼上(&&P)",
 		"貼上",
 		"貼上",
+		"貼上",
 		"隨語法醒目提示複製",
 	],
 	"vs/editor/contrib/codeAction/codeActionCommands": [
@@ -540,48 +617,11 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"游標復原",
 		"游標重做",
 	],
-	"vs/editor/contrib/documentSymbols/outlineTree": [
-		"陣列符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
-		"布林值符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
-		"類別符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
-		"色彩符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
-		"常數符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
-		"建構函式符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
-		"列舉值符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
-		"列舉值成員符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
-		"事件符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
-		"欄位符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
-		"檔案符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
-		"資料夾符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
-		"函式符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
-		"介面符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
-		"索引鍵符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
-		"關鍵字符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
-		"方法符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
-		"模組符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
-		"命名空間符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
-		"Null 符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
-		"數字符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
-		"物件符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
-		"運算子符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
-		"套件符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
-		"屬性符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
-		"參考符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
-		"程式碼片段符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
-		"字串符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
-		"結構符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
-		"文字符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
-		"型別參數符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
-		"單位符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
-		"變數符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
-	],
 	"vs/editor/contrib/find/findController": [
 		"尋找",
 		"尋找(&&F)",
 		"尋找選取項目",
 		"尋找下一個",
-		"尋找下一個",
-		"尋找上一個",
 		"尋找上一個",
 		"尋找下一個選取項目",
 		"尋找上一個選取項目",
@@ -589,6 +629,13 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"取代(&&R)",
 	],
 	"vs/editor/contrib/find/findWidget": [
+		"編輯器尋找小工具中 [在選取範圍中尋找] 的圖示。",
+		"表示編輯器尋找小工具已摺疊的圖示。",
+		"表示編輯器尋找小工具已展開的圖示。",
+		"編輯器尋找小工具中 [取代] 的圖示。",
+		"編輯器尋找小工具中 [全部取代] 的圖示。",
+		"編輯器尋找小工具中 [尋找上一個] 的圖示。",
+		"編輯器尋找小工具中 [尋找下一個] 的圖示。",
 		"尋找",
 		"尋找",
 		"上一個符合項目",
@@ -618,12 +665,18 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"摺疊全部區塊註解",
 		"摺疊所有區域",
 		"展開所有區域",
+		"折疊所選區域以外的所有區域",
+		"展開所選區域以外的所有區域",
 		"全部摺疊",
 		"全部展開",
 		"摺疊層級 {0}",
 		"已摺疊範圍後的背景色彩。色彩不得處於不透明狀態，以免隱藏底層裝飾。",
 		"編輯器裝訂邊的摺疊控制項色彩。",
 	],
+	"vs/editor/contrib/folding/foldingDecorations": [
+		"編輯器字符邊界中 [展開的範圍] 的圖示。",
+		"編輯器字符邊界中 [摺疊的範圍] 的圖示。",
+	],
 	"vs/editor/contrib/fontZoom/fontZoom": [
 		"編輯器字體放大",
 		"編輯器字型縮小",
@@ -641,7 +694,9 @@ define("vs/editor/editor.main.nls.zh-tw", {
 	],
 	"vs/editor/contrib/gotoError/gotoError": [
 		"移至下一個問題 (錯誤, 警告, 資訊)",
+		"[前往下一個標記] 的圖示。",
 		"移至上一個問題 (錯誤, 警告, 資訊)",
+		"[前往上一個標記] 的圖示。",
 		"移至檔案裡面的下一個問題 (錯誤, 警告, 資訊)",
 		"下一個問題(&&P)",
 		"移至檔案裡面的上一個問題 (錯誤, 警告, 資訊)",
@@ -705,6 +760,7 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"按一下以顯示 {0} 項定義。",
 	],
 	"vs/editor/contrib/gotoSymbol/peek/referencesController": [
+		"是否顯示參考瞄核，例如「瞄核參考」或「瞄核定義」",
 		"正在載入...",
 		"{0} ({1})",
 	],
@@ -720,6 +776,7 @@ define("vs/editor/editor.main.nls.zh-tw", {
 	],
 	"vs/editor/contrib/gotoSymbol/referencesModel": [
 		"個符號位於 {0} 中的第 {1} 行第 {2} 欄",
+		"符號位於 {0} 中的第 {1} 行第 {2}、{3} 欄",
 		"1 個符號位於 {0}, 完整路徑 {1}",
 		"{0} 個符號位於 {1}, 完整路徑 {2}",
 		"找不到結果",
@@ -728,6 +785,7 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"在 {1} 個檔案中找到 {0} 個符號",
 	],
 	"vs/editor/contrib/gotoSymbol/symbolNavigation": [
+		"是否有只能透過鍵盤瀏覽的符號位置。",
 		"{1} 的符號 {0}，{2} 為下一個",
 		"{1} 的符號 {0}",
 	],
@@ -735,9 +793,12 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"動態顯示",
 		"顯示定義預覽懸停",
 	],
-	"vs/editor/contrib/hover/modesContentHover": [
+	"vs/editor/contrib/hover/markdownHoverParticipant": [
 		"正在載入...",
-		"瞄孔問題",
+	],
+	"vs/editor/contrib/hover/markerHoverParticipant": [
+		"檢視問題",
+		"沒有可用的快速修正",
 		"正在檢查快速修正...",
 		"沒有可用的快速修正",
 		"快速修復...",
@@ -757,6 +818,18 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"重新將行縮排",
 		"重新將選取的行縮排",
 	],
+	"vs/editor/contrib/inlineCompletions/ghostTextController": [
+		"是否顯示內嵌建議",
+		"內嵌建議是否以空白字元開頭",
+		"顯示下一個內嵌建議",
+		"顯示上一個內嵌建議",
+		"觸發內嵌建議",
+	],
+	"vs/editor/contrib/inlineCompletions/inlineCompletionsHoverParticipant": [
+		"下一步",
+		"上一步",
+		"接受",
+	],
 	"vs/editor/contrib/linesOperations/linesOperations": [
 		"將行向上複製",
 		"將行向上複製(&&C)",
@@ -783,6 +856,11 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"轉換到大寫",
 		"轉換到小寫",
 		"轉換為字首大寫",
+		"轉換為底線連接字",
+	],
+	"vs/editor/contrib/linkedEditing/linkedEditing": [
+		"開始連結的編輯",
+		"當編輯器自動重新命名類型時的背景色彩。",
 	],
 	"vs/editor/contrib/links/links": [
 		"執行命令",
@@ -791,14 +869,18 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"ctrl + 按一下",
 		"選項 + 按一下",
 		"alt + 按一下",
+		"執行命令 {0}",
 		"因為此連結的格式不正確，所以無法開啟: {0}",
 		"因為此連結目標遺失，所以無法開啟。",
 		"開啟連結",
 	],
 	"vs/editor/contrib/message/messageController": [
+		"編輯器目前是否正在顯示內嵌訊息",
 		"無法在唯讀編輯器中編輯",
 	],
 	"vs/editor/contrib/multicursor/multicursor": [
+		"新增的資料指標: {0}",
+		"新增的資料指標: {0}",
 		"在上方加入游標",
 		"在上方新增游標(&&A)",
 		"在下方加入游標",
@@ -821,9 +903,12 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"觸發參數提示",
 	],
 	"vs/editor/contrib/parameterHints/parameterHintsWidget": [
+		"[顯示下一個參數提示] 的圖示。",
+		"[顯示上一個參數提示] 的圖示。",
 		"{0}，提示",
 	],
 	"vs/editor/contrib/peekView/peekView": [
+		"目前的程式碼編輯器是否內嵌於瞄核內",
 		"關閉",
 		"預覽檢視標題區域的背景色彩。",
 		"預覽檢視標題的色彩。",
@@ -842,7 +927,7 @@ define("vs/editor/editor.main.nls.zh-tw", {
 	],
 	"vs/editor/contrib/quickAccess/gotoLineQuickAccess": [
 		"先開啟文字編輯器，前往某一行。",
-		"前往第 {0} 行和第 {1} 欄。",
+		"前往第 {0} 行的第 {1} 個字元。",
 		"前往第 {0} 行。",
 		"目前行: {0}，字元: {1}。請鍵入介於 1 到 {2} 之間行號，導覽至該行。",
 		"目前行: {0}，字元: {1}。請鍵入要導覽至的行號。",
@@ -882,10 +967,6 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"欄位 ({0})",
 		"常數 ({0})",
 	],
-	"vs/editor/contrib/rename/onTypeRename": [
-		"依類型重新命名符號",
-		"當編輯器自動重新命名類型時的背景色彩。",
-	],
 	"vs/editor/contrib/rename/rename": [
 		"沒有結果。",
 		"解析重新命名位置時發生未知的錯誤",
@@ -898,6 +979,7 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"啟用/停用重新命名前先預覽變更的功能",
 	],
 	"vs/editor/contrib/rename/renameInputField": [
+		"是否顯示重新命名輸入小工具",
 		"為輸入重新命名。請鍵入新名稱，然後按 Enter 以認可。",
 		"按 {0} 進行重新命名，按 {1} 進行預覽",
 	],
@@ -907,6 +989,11 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"縮小選取項目",
 		"壓縮選取範圍(&&S)",
 	],
+	"vs/editor/contrib/snippet/snippetController2": [
+		"編輯器目前是否在程式碼片段模式中",
+		"在程式碼片段模式中是否有下一個定位停駐點",
+		"在程式碼片段模式中是否有上一個定位停駐點",
+	],
 	"vs/editor/contrib/snippet/snippetVariables": [
 		"星期天",
 		"星期一",
@@ -947,31 +1034,87 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"11 月",
 		"12 月",
 	],
+	"vs/editor/contrib/suggest/suggest": [
+		"是否顯示建議",
+		"是否顯示建議詳細資料",
+		"是否有多個建議可以挑選",
+		"插入目前的建議會產生變更，或已鍵入所有項目",
+		"是否在按下 Enter 時插入建議",
+		"目前的建議是否有插入和取代行為",
+		"預設行為是插入或取代",
+		"目前的建議是否支援解決更多詳細資料",
+	],
 	"vs/editor/contrib/suggest/suggestController": [
-		"Accepting \'{0}\' made {1} additional edits",
+		"接受 ‘{0}’ 進行了其他 {1} 項編輯",
 		"觸發建議",
-		"{0} 以插入",
-		"{0} 以插入",
-		"{0} 以取代",
-		"{0} 以取代",
-		"{0} 以插入",
+		"插入",
+		"插入",
+		"取代",
+		"取代",
+		"插入",
 		"顯示更少",
 		"顯示更多",
+		"重設建議小工具大小",
 	],
 	"vs/editor/contrib/suggest/suggestWidget": [
 		"建議小工具的背景色彩。",
 		"建議小工具的邊界色彩。",
 		"建議小工具的前景色彩。",
+		"建議小工具中所選項目的前景色彩。",
 		"建議小工具中所選項目的背景色彩。",
 		"建議小工具中相符醒目提示的色彩。",
-		"閱讀較多 ({0})",
-		"閱讀較少 ({0})",
-		"正在載入...",
+		"當項目成為焦點時，相符項目的色彩在建議小工具中會醒目顯示。",
 		"正在載入...",
 		"無建議。",
 		"{0}，文件: {1}",
 		"建議",
 	],
+	"vs/editor/contrib/suggest/suggestWidgetDetails": [
+		"關閉",
+		"正在載入...",
+	],
+	"vs/editor/contrib/suggest/suggestWidgetRenderer": [
+		"建議小工具中 [更多詳細資訊] 的圖示。",
+		"閱讀更多",
+	],
+	"vs/editor/contrib/suggest/suggestWidgetStatus": [
+		"{0} ({1})",
+	],
+	"vs/editor/contrib/symbolIcons/symbolIcons": [
+		"陣列符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
+		"布林值符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
+		"類別符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
+		"色彩符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
+		"常數符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
+		"建構函式符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
+		"列舉值符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
+		"列舉值成員符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
+		"事件符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
+		"欄位符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
+		"檔案符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
+		"資料夾符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
+		"函式符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
+		"介面符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
+		"索引鍵符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
+		"關鍵字符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
+		"方法符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
+		"模組符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
+		"命名空間符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
+		"Null 符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
+		"數字符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
+		"物件符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
+		"運算子符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
+		"套件符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
+		"屬性符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
+		"參考符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
+		"程式碼片段符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
+		"字串符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
+		"結構符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
+		"文字符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
+		"型別參數符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
+		"單位符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
+		"變數符號的前景色彩。這些符號會出現在大綱、階層連結和建議小工具中。",
+	],
 	"vs/editor/contrib/toggleTabFocusMode/toggleTabFocusMode": [
 		"切換 TAB 鍵移動焦點",
 		"按 Tab 現在會將焦點移至下一個可設定焦點的元素。",
@@ -998,16 +1141,27 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"移至上一個反白符號",
 		"觸發符號反白顯示",
 	],
+	"vs/editor/contrib/wordOperations/wordOperations": [
+		"刪除字組",
+	],
 	"vs/platform/actions/browser/menuEntryActionViewItem": [
 		"{0} ({1})",
+		"{0} ({1})",
 	],
 	"vs/platform/configuration/common/configurationRegistry": [
 		"預設語言組態覆寫",
 		"設定要針對語言覆寫的編輯器設定。",
 		"這個設定不支援以語言為根據的組態。",
+		"無法註冊空白屬性",
 		"無法註冊 \'{0}\'。這符合用於描述語言專用編輯器設定的屬性模式 \'\\\\[.*\\\\]$\'。請使用 \'configurationDefaults\' 貢獻。",
 		"無法註冊 \'{0}\'。此屬性已經註冊。",
 	],
+	"vs/platform/contextkey/browser/contextKeyService": [
+		"傳回有關內容索引鍵資訊的命令",
+	],
+	"vs/platform/contextkey/common/contextkeys": [
+		"作業系統是否為 Windows",
+	],
 	"vs/platform/keybinding/common/abstractKeybindingService": [
 		"已按下 ({0})。等待第二個套索鍵...",
 		"按鍵組合 ({0}, {1}) 不是命令。",
@@ -1017,7 +1171,7 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"對應Windows和Linux的\'Control\'與對應 macOS 的\'Command\'。",
 		"對應Windows和Linux的\'Alt\'與對應macOS的\'Option\'。",
 		"透過滑鼠多選，用於在樹狀目錄與清單中新增項目的輔助按鍵 (例如在總管中開啟編輯器 及 SCM 檢視)。\'在側邊開啟\' 滑鼠手勢 (若支援) 將會適應以避免和多選輔助按鍵衝突。",
-		"控制如何使用滑鼠在樹狀目錄與清單中開啟項目 (若有支援)。對於樹狀目錄中具子系的父系而言，此設定會控制應以滑鼠按一下或按兩下展開父系。注意，某些樹狀目錄或清單若不適用此設定則會予以忽略。",
+		"控制如何使用滑鼠 (如支援此用法) 開啟樹狀目錄與清單中的項目。若不適用，某些樹狀目錄與清單可能會選擇忽略此設定。",
 		"控制在工作台中，清單與樹狀結構是否支援水平捲動。警告: 開啟此設定將會影響效能。",
 		"控制樹狀結構縮排 (像素)。",
 		"控制樹系是否應轉譯縮排輔助線。",
@@ -1027,6 +1181,7 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"篩選鍵盤瀏覽會篩掉並隱藏不符合鍵盤輸入的所有元素。",
 		"控制 Workbench 中清單和樹狀結構的鍵盤瀏覽樣式。可以是簡易的、醒目提示和篩選。",
 		"控制是否只要鍵入即可自動觸發清單和樹狀結構中的鍵盤瀏覽。若設為 `false`，只有在執行 `list.toggleKeyboardNavigation` 命令時，才會觸發鍵盤瀏覽，您可為其指定鍵盤快速鍵。",
+		"控制當按下資料夾名稱時，樹狀目錄資料夾的展開方式。請注意，若不適用，某些樹狀目錄和清單可能會選擇忽略此設定。",
 	],
 	"vs/platform/markers/common/markers": [
 		"錯誤",
@@ -1038,6 +1193,7 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"最近使用的",
 		"其他命令",
 		"命令 \'{0}\' 造成錯誤 ({1})",
+		"確定",
 	],
 	"vs/platform/quickinput/browser/helpQuickAccess": [
 		"全域命令",
@@ -1081,10 +1237,13 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"動態顯示時捲軸滑桿的背景顏色。",
 		"當點擊時捲軸滑桿的背景顏色。",
 		"長時間運行進度條的背景色彩.",
+		"編輯器中錯誤文字的背景色彩。其不得為不透明色彩，以免隱藏底層裝飾。",
 		"編輯器內錯誤提示線的前景色彩.",
 		"編輯器中錯誤方塊的框線色彩。",
+		"編輯器中警告文字的背景色彩。其不得為不透明色彩，以免隱藏底層裝飾。",
 		"編輯器內警告提示線的前景色彩.",
 		"編輯器中的警告方塊框線色彩。",
+		"編輯器中資訊文字的背景色彩。其不得為不透明色彩，以免隱藏底層裝飾。",
 		"編輯器內資訊提示線的前景色彩",
 		"編輯器中的資訊方塊框線色彩。",
 		"編輯器內提示訊息的提示線前景色彩",
@@ -1094,12 +1253,16 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"編輯器小工具的背景色彩，例如尋找/取代。",
 		"編輯器小工具 (例如尋找/取代) 的前景色彩。",
 		"編輯器小工具的邊界色彩。小工具選擇擁有邊界或色彩未被小工具覆寫時，才會使用色彩。",
-		"編輯器小工具之調整大小列的邊界色彩。只在小工具選擇具有調整大小邊界且未覆寫該色彩時，才使用該色彩。\r\n",
+		"編輯器小工具之調整大小列的邊界色彩。只在小工具選擇具有調整大小邊界且未覆寫該色彩時，才使用該色彩。",
 		"快速選擇器背景色彩。該快速選擇器小工具是類似命令選擇區的選擇器容器。",
 		"快速選擇器前景色彩。快速選擇器小工具是類似命令選擇區等選擇器的容器。",
 		"快速選擇器標題背景色彩。快速選擇器小工具是類似命令選擇區的選擇器容器。",
 		"分組標籤的快速選擇器色彩。",
 		"分組邊界的快速選擇器色彩。",
+		"金鑰綁定標籤背景色彩。按鍵綁定標籤用來代表鍵盤快速鍵。",
+		"金鑰綁定標籤前景色彩。按鍵綁定標籤用來代表鍵盤快速鍵。",
+		"金鑰綁定標籤邊框色彩。按鍵綁定標籤用來代表鍵盤快速鍵。",
+		"金鑰綁定標籤邊框底部色彩。按鍵綁定標籤用來代表鍵盤快速鍵。",
 		"編輯器選取範圍的色彩。",
 		"為選取的文字顏色高對比化",
 		"非使用中編輯器內的選取項目色彩。其不得為不透明色彩，以免隱藏底層裝飾。",
@@ -1117,6 +1280,8 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"編輯器動態顯示的框線色彩。",
 		"編輯器暫留狀態列的背景色彩。",
 		"使用中之連結的色彩。",
+		"內嵌提示的前景色彩",
+		"內嵌提示的背景色彩",
 		"用於燈泡動作圖示的色彩。",
 		"用於燈泡自動修正動作圖示的色彩。",
 		"已插入文字的背景色彩。其不得為不透明色彩，以免隱藏底層裝飾。",
@@ -1127,19 +1292,26 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"Diff 編輯器的斜紋填滿色彩。斜紋填滿用於並排 Diff 檢視。",
 		"當清單/樹狀為使用中狀態時，焦點項目的清單/樹狀背景色彩。使用中的清單/樹狀有鍵盤焦點，非使用中者則沒有。",
 		"當清單/樹狀為使用中狀態時，焦點項目的清單/樹狀前景色彩。使用中的清單/樹狀有鍵盤焦點，非使用中者則沒有。",
+		"當清單/樹狀目錄為使用中狀態時，焦點項目的清單/樹狀目錄外框色彩。使用中的清單/樹狀目錄有鍵盤焦點，非使用中者則沒有。",
 		"當清單/樹狀為使用中狀態時，所選項目的清單/樹狀背景色彩。使用中的清單/樹狀有鍵盤焦點，非使用中者則沒有。",
 		"當清單/樹狀為使用中狀態時，所選項目的清單/樹狀前景色彩。使用中的清單/樹狀有鍵盤焦點，非使用中者則沒有。",
 		"當清單/樹狀為非使用中狀態時，所選項目的清單/樹狀背景色彩。使用中的清單/樹狀有鍵盤焦點，非使用中者則沒有。",
 		"當清單/樹狀為使用中狀態時，所選項目的清單/樹狀前景色彩。使用中的清單/樹狀有鍵盤焦點，非使用中則沒有。",
 		"當清單/樹狀為非使用中狀態時，焦點項目的清單/樹狀背景色彩。使用中的清單/樹狀有鍵盤焦點，非使用中者則沒有。",
+		"當清單/樹狀目錄為非使用中狀態時，焦點項目的清單/樹狀目錄外框色彩。使用中的清單/樹狀目錄有鍵盤焦點，非使用中者則沒有。",
 		"使用滑鼠暫留在項目時的清單/樹狀背景。",
 		"滑鼠暫留在項目時的清單/樹狀前景。",
 		"使用滑鼠四處移動項目時的清單/樹狀拖放背景。",
 		"在清單/樹狀內搜尋時，相符醒目提示的清單/樹狀前景色彩。",
+		"在清單/樹狀內搜尋時，相符項目的清單/樹狀結構前景色彩會針對主動焦點項目進行強調顯示。",
 		"清單和樹狀結構中類型篩選小工具的背景色彩。",
 		"清單和樹狀結構中類型篩選小工具的大綱色彩。",
 		"在沒有相符項目時，清單和樹狀結構中類型篩選小工具的大綱色彩。",
 		"縮排輔助線的樹狀筆觸色彩。",
+		"縮排輔助線的樹狀筆觸色彩。",
+		"請改用 quickInputList.focusBackground",
+		"焦點項目的快速選擇器前景色彩。",
+		"焦點項目的快速選擇器背景色彩。",
 		"功能表的邊框色彩。",
 		"功能表項目的前景色彩。",
 		"功能表項目的背景色彩。",
@@ -1165,6 +1337,11 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"用於問題警告圖示的色彩。",
 		"用於問題資訊圖示的色彩。",
 	],
+	"vs/platform/theme/common/iconRegistry": [
+		"要使用的字型識別碼。如未設定，就會使用最先定義的字型。",
+		"與圖示定義建立關聯的字型字元。",
+		"小工具中關閉動作的圖示。",
+	],
 	"vs/platform/undoRedo/common/undoRedoService": [
 		"已在磁碟上關閉並修改以下檔案: {0}。",
 		"下列檔案已使用不相容的方式修改: {0}。",
@@ -1178,6 +1355,9 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"復原此檔案",
 		"取消",
 		"因為已經有正在執行的復原或重做作業，所以無法復原 \'{0}\'。",
+		"要復原 \'{0}\' 嗎?",
+		"復原",
+		"取消",
 		"無法復原所有檔案的 \'{0}\'。{1}",
 		"無法復原所有檔案的 \'{0}\'。{1}",
 		"因為已對 {1} 進行變更，所以無法復原所有檔案的 \'{0}\'",
