@@ -2,7 +2,6 @@
  *  Copyright (c) Microsoft Corporation. All rights reserved.
  *  Licensed under the MIT License. See License.txt in the project root for license information.
  *--------------------------------------------------------------------------------------------*/
-import * as browser from '../../../base/browser/browser.js';
 import { PageCoordinates } from '../editorDom.js';
 import { PartFingerprints } from '../view/viewPart.js';
 import { ViewLine } from '../viewParts/lines/viewLine.js';
@@ -10,6 +9,31 @@ import { Position } from '../../common/core/position.js';
 import { Range as EditorRange } from '../../common/core/range.js';
 import { CursorColumns } from '../../common/controller/cursorCommon.js';
 import * as dom from '../../../base/browser/dom.js';
+import { AtomicTabMoveOperations } from '../../common/controller/cursorAtomicMoveOperations.js';
+class UnknownHitTestResult {
+    constructor(hitTarget = null) {
+        this.hitTarget = hitTarget;
+        this.type = 0 /* Unknown */;
+    }
+}
+class ContentHitTestResult {
+    constructor(position, spanNode) {
+        this.position = position;
+        this.spanNode = spanNode;
+        this.type = 1 /* Content */;
+    }
+}
+var HitTestResult;
+(function (HitTestResult) {
+    function createFromDOMInfo(ctx, spanNode, offset) {
+        const position = ctx.getPositionFromDOMInfo(spanNode, offset);
+        if (position) {
+            return new ContentHitTestResult(position, spanNode);
+        }
+        return new UnknownHitTestResult(spanNode);
+    }
+    HitTestResult.createFromDOMInfo = createFromDOMInfo;
+})(HitTestResult || (HitTestResult = {}));
 export class PointerHandlerLastRenderData {
     constructor(lastViewCursorsRenderData, lastTextareaPosition) {
         this.lastViewCursorsRenderData = lastViewCursorsRenderData;
@@ -119,10 +143,11 @@ export class HitTestContext {
     constructor(context, viewHelper, lastRenderData) {
         this.model = context.model;
         const options = context.configuration.options;
-        this.layoutInfo = options.get(117 /* layoutInfo */);
+        this.layoutInfo = options.get(128 /* layoutInfo */);
         this.viewDomNode = viewHelper.viewDomNode;
-        this.lineHeight = options.get(51 /* lineHeight */);
-        this.typicalHalfwidthCharacterWidth = options.get(36 /* fontInfo */).typicalHalfwidthCharacterWidth;
+        this.lineHeight = options.get(56 /* lineHeight */);
+        this.stickyTabStops = options.get(102 /* stickyTabStops */);
+        this.typicalHalfwidthCharacterWidth = options.get(40 /* fontInfo */).typicalHalfwidthCharacterWidth;
         this.lastRenderData = lastRenderData;
         this._context = context;
         this._viewHelper = viewHelper;
@@ -134,7 +159,11 @@ export class HitTestContext {
         // The target is either a view zone or the empty space after the last view-line
         const viewZoneWhitespace = context.viewLayout.getWhitespaceAtVerticalOffset(mouseVerticalOffset);
         if (viewZoneWhitespace) {
-            let viewZoneMiddle = viewZoneWhitespace.verticalOffset + viewZoneWhitespace.height / 2, lineCount = context.model.getLineCount(), positionBefore = null, position, positionAfter = null;
+            const viewZoneMiddle = viewZoneWhitespace.verticalOffset + viewZoneWhitespace.height / 2;
+            const lineCount = context.model.getLineCount();
+            let positionBefore = null;
+            let position;
+            let positionAfter = null;
             if (viewZoneWhitespace.afterLineNumber !== lineCount) {
                 // There are more lines after this view zone
                 positionAfter = new Position(viewZoneWhitespace.afterLineNumber + 1, 1);
@@ -188,6 +217,12 @@ export class HitTestContext {
     isAfterLines(mouseVerticalOffset) {
         return this._context.viewLayout.isAfterLines(mouseVerticalOffset);
     }
+    isInTopPadding(mouseVerticalOffset) {
+        return this._context.viewLayout.isInTopPadding(mouseVerticalOffset);
+    }
+    isInBottomPadding(mouseVerticalOffset) {
+        return this._context.viewLayout.isInBottomPadding(mouseVerticalOffset);
+    }
     getVerticalOffsetForLineNumber(lineNumber) {
         return this._context.viewLayout.getVerticalOffsetForLineNumber(lineNumber);
     }
@@ -249,6 +284,8 @@ class HitTestRequest extends BareHitTestRequest {
     toString() {
         return `pos(${this.pos.x},${this.pos.y}), editorPos(${this.editorPos.x},${this.editorPos.y}), mouseVerticalOffset: ${this.mouseVerticalOffset}, mouseContentHorizontalOffset: ${this.mouseContentHorizontalOffset}\n\ttarget: ${this.target ? this.target.outerHTML : null}`;
     }
+    // public fulfill(type: MouseTargetType.OVERVIEW_RULER, position?: Position | null, range?: EditorRange | null, detail?: any): MouseTarget;
+    // public fulfill(type: MouseTargetType.OUTSIDE_EDITOR, position?: Position | null, range?: EditorRange | null, detail?: any): MouseTarget;
     fulfill(type, position = null, range = null, detail = null) {
         let mouseColumn = this.mouseColumn;
         if (position && position.column < this._ctx.model.getLineMaxColumn(position.lineNumber)) {
@@ -308,8 +345,8 @@ export class MouseTargetFactory {
                 return request.fulfill(0 /* UNKNOWN */);
             }
             const hitTestResult = MouseTargetFactory._doHitTest(ctx, request);
-            if (hitTestResult.position) {
-                return MouseTargetFactory.createMouseTargetFromHitTestPosition(ctx, request, hitTestResult.position.lineNumber, hitTestResult.position.column);
+            if (hitTestResult.type === 1 /* Content */) {
+                return MouseTargetFactory.createMouseTargetFromHitTestPosition(ctx, request, hitTestResult.spanNode, hitTestResult.position);
             }
             return this._createMouseTarget(ctx, request.withTarget(hitTestResult.hitTarget), true);
         }
@@ -360,7 +397,7 @@ export class MouseTargetFactory {
             const lastViewCursorsRenderData = ctx.lastRenderData.lastViewCursorsRenderData;
             for (const d of lastViewCursorsRenderData) {
                 if (request.target === d.domNode) {
-                    return request.fulfill(6 /* CONTENT_TEXT */, d.position);
+                    return request.fulfill(6 /* CONTENT_TEXT */, d.position, null, { mightBeForeignElement: false });
                 }
             }
         }
@@ -384,7 +421,7 @@ export class MouseTargetFactory {
                 const cursorVerticalOffset = ctx.getVerticalOffsetForLineNumber(d.position.lineNumber);
                 if (cursorVerticalOffset <= mouseVerticalOffset
                     && mouseVerticalOffset <= cursorVerticalOffset + d.height) {
-                    return request.fulfill(6 /* CONTENT_TEXT */, d.position);
+                    return request.fulfill(6 /* CONTENT_TEXT */, d.position, null, { mightBeForeignElement: false });
                 }
             }
         }
@@ -402,7 +439,7 @@ export class MouseTargetFactory {
         // Is it the textarea?
         if (ElementPath.isTextArea(request.targetPath)) {
             if (ctx.lastRenderData.lastTextareaPosition) {
-                return request.fulfill(6 /* CONTENT_TEXT */, ctx.lastRenderData.lastTextareaPosition);
+                return request.fulfill(6 /* CONTENT_TEXT */, ctx.lastRenderData.lastTextareaPosition, null, { mightBeForeignElement: false });
             }
             return request.fulfill(1 /* TEXTAREA */, ctx.lastRenderData.lastTextareaPosition);
         }
@@ -440,36 +477,39 @@ export class MouseTargetFactory {
         if (!ElementPath.isChildOfViewLines(request.targetPath)) {
             return null;
         }
+        if (ctx.isInTopPadding(request.mouseVerticalOffset)) {
+            return request.fulfill(7 /* CONTENT_EMPTY */, new Position(1, 1), null, EMPTY_CONTENT_AFTER_LINES);
+        }
         // Check if it is below any lines and any view zones
-        if (ctx.isAfterLines(request.mouseVerticalOffset)) {
+        if (ctx.isAfterLines(request.mouseVerticalOffset) || ctx.isInBottomPadding(request.mouseVerticalOffset)) {
             // This most likely indicates it happened after the last view-line
             const lineCount = ctx.model.getLineCount();
             const maxLineColumn = ctx.model.getLineMaxColumn(lineCount);
-            return request.fulfill(7 /* CONTENT_EMPTY */, new Position(lineCount, maxLineColumn), undefined, EMPTY_CONTENT_AFTER_LINES);
+            return request.fulfill(7 /* CONTENT_EMPTY */, new Position(lineCount, maxLineColumn), null, EMPTY_CONTENT_AFTER_LINES);
         }
         if (domHitTestExecuted) {
             // Check if we are hitting a view-line (can happen in the case of inline decorations on empty lines)
-            // See https://github.com/Microsoft/vscode/issues/46942
+            // See https://github.com/microsoft/vscode/issues/46942
             if (ElementPath.isStrictChildOfViewLines(request.targetPath)) {
                 const lineNumber = ctx.getLineNumberAtVerticalOffset(request.mouseVerticalOffset);
                 if (ctx.model.getLineLength(lineNumber) === 0) {
                     const lineWidth = ctx.getLineWidth(lineNumber);
                     const detail = createEmptyContentDataInLines(request.mouseContentHorizontalOffset - lineWidth);
-                    return request.fulfill(7 /* CONTENT_EMPTY */, new Position(lineNumber, 1), undefined, detail);
+                    return request.fulfill(7 /* CONTENT_EMPTY */, new Position(lineNumber, 1), null, detail);
                 }
                 const lineWidth = ctx.getLineWidth(lineNumber);
                 if (request.mouseContentHorizontalOffset >= lineWidth) {
                     const detail = createEmptyContentDataInLines(request.mouseContentHorizontalOffset - lineWidth);
                     const pos = new Position(lineNumber, ctx.model.getLineMaxColumn(lineNumber));
-                    return request.fulfill(7 /* CONTENT_EMPTY */, pos, undefined, detail);
+                    return request.fulfill(7 /* CONTENT_EMPTY */, pos, null, detail);
                 }
             }
             // We have already executed hit test...
             return request.fulfill(0 /* UNKNOWN */);
         }
         const hitTestResult = MouseTargetFactory._doHitTest(ctx, request);
-        if (hitTestResult.position) {
-            return MouseTargetFactory.createMouseTargetFromHitTestPosition(ctx, request, hitTestResult.position.lineNumber, hitTestResult.position.column);
+        if (hitTestResult.type === 1 /* Content */) {
+            return MouseTargetFactory.createMouseTargetFromHitTestPosition(ctx, request, hitTestResult.spanNode, hitTestResult.position);
         }
         return this._createMouseTarget(ctx, request.withTarget(hitTestResult.hitTarget), true);
     }
@@ -506,9 +546,9 @@ export class MouseTargetFactory {
     }
     getMouseColumn(editorPos, pos) {
         const options = this._context.configuration.options;
-        const layoutInfo = options.get(117 /* layoutInfo */);
+        const layoutInfo = options.get(128 /* layoutInfo */);
         const mouseContentHorizontalOffset = this._context.viewLayout.getCurrentScrollLeft() + pos.x - editorPos.x - layoutInfo.contentLeft;
-        return MouseTargetFactory._getMouseColumn(mouseContentHorizontalOffset, options.get(36 /* fontInfo */).typicalHalfwidthCharacterWidth);
+        return MouseTargetFactory._getMouseColumn(mouseContentHorizontalOffset, options.get(40 /* fontInfo */).typicalHalfwidthCharacterWidth);
     }
     static _getMouseColumn(mouseContentHorizontalOffset, typicalHalfwidthCharacterWidth) {
         if (mouseContentHorizontalOffset < 0) {
@@ -517,17 +557,13 @@ export class MouseTargetFactory {
         const chars = Math.round(mouseContentHorizontalOffset / typicalHalfwidthCharacterWidth);
         return (chars + 1);
     }
-    static createMouseTargetFromHitTestPosition(ctx, request, lineNumber, column) {
-        const pos = new Position(lineNumber, column);
+    static createMouseTargetFromHitTestPosition(ctx, request, spanNode, pos) {
+        const lineNumber = pos.lineNumber;
+        const column = pos.column;
         const lineWidth = ctx.getLineWidth(lineNumber);
         if (request.mouseContentHorizontalOffset > lineWidth) {
-            if (browser.isEdge && pos.column === 1) {
-                // See https://github.com/Microsoft/vscode/issues/10875
-                const detail = createEmptyContentDataInLines(request.mouseContentHorizontalOffset - lineWidth);
-                return request.fulfill(7 /* CONTENT_EMPTY */, new Position(lineNumber, ctx.model.getLineMaxColumn(lineNumber)), undefined, detail);
-            }
             const detail = createEmptyContentDataInLines(request.mouseContentHorizontalOffset - lineWidth);
-            return request.fulfill(7 /* CONTENT_EMPTY */, pos, undefined, detail);
+            return request.fulfill(7 /* CONTENT_EMPTY */, pos, null, detail);
         }
         const visibleRange = ctx.visibleRangeForPosition(lineNumber, column);
         if (!visibleRange) {
@@ -535,7 +571,7 @@ export class MouseTargetFactory {
         }
         const columnHorizontalOffset = visibleRange.left;
         if (request.mouseContentHorizontalOffset === columnHorizontalOffset) {
-            return request.fulfill(6 /* CONTENT_TEXT */, pos);
+            return request.fulfill(6 /* CONTENT_TEXT */, pos, null, { mightBeForeignElement: false });
         }
         const points = [];
         points.push({ offset: visibleRange.left, column: column });
@@ -553,15 +589,18 @@ export class MouseTargetFactory {
             }
         }
         points.sort((a, b) => a.offset - b.offset);
+        const mouseCoordinates = request.pos.toClientCoordinates();
+        const spanNodeClientRect = spanNode.getBoundingClientRect();
+        const mouseIsOverSpanNode = (spanNodeClientRect.left <= mouseCoordinates.clientX && mouseCoordinates.clientX <= spanNodeClientRect.right);
         for (let i = 1; i < points.length; i++) {
             const prev = points[i - 1];
             const curr = points[i];
             if (prev.offset <= request.mouseContentHorizontalOffset && request.mouseContentHorizontalOffset <= curr.offset) {
                 const rng = new EditorRange(lineNumber, prev.column, lineNumber, curr.column);
-                return request.fulfill(6 /* CONTENT_TEXT */, pos, rng);
+                return request.fulfill(6 /* CONTENT_TEXT */, pos, rng, { mightBeForeignElement: !mouseIsOverSpanNode });
             }
         }
-        return request.fulfill(6 /* CONTENT_TEXT */, pos);
+        return request.fulfill(6 /* CONTENT_TEXT */, pos, null, { mightBeForeignElement: !mouseIsOverSpanNode });
     }
     /**
      * Most probably WebKit browsers and Edge
@@ -581,7 +620,7 @@ export class MouseTargetFactory {
         }
         const adjustedPage = new PageCoordinates(request.pos.x, adjustedPageY);
         const r = this._actualDoHitTestWithCaretRangeFromPoint(ctx, adjustedPage.toClientCoordinates());
-        if (r.position) {
+        if (r.type === 1 /* Content */) {
             return r;
         }
         // Also try to hit test without the adjustment (for the edge cases that we are near the top or bottom)
@@ -602,14 +641,10 @@ export class MouseTargetFactory {
             range = document.caretRangeFromPoint(coords.clientX, coords.clientY);
         }
         if (!range || !range.startContainer) {
-            return {
-                position: null,
-                hitTarget: null
-            };
+            return new UnknownHitTestResult();
         }
         // Chrome always hits a TEXT_NODE, while Edge sometimes hits a token span
         const startContainer = range.startContainer;
-        let hitTarget = null;
         if (startContainer.nodeType === startContainer.TEXT_NODE) {
             // startContainer is expected to be the token text
             const parent1 = startContainer.parentNode; // expected to be the token span
@@ -617,14 +652,10 @@ export class MouseTargetFactory {
             const parent3 = parent2 ? parent2.parentNode : null; // expected to be the view line div
             const parent3ClassName = parent3 && parent3.nodeType === parent3.ELEMENT_NODE ? parent3.className : null;
             if (parent3ClassName === ViewLine.CLASS_NAME) {
-                const p = ctx.getPositionFromDOMInfo(parent1, range.startOffset);
-                return {
-                    position: p,
-                    hitTarget: null
-                };
+                return HitTestResult.createFromDOMInfo(ctx, parent1, range.startOffset);
             }
             else {
-                hitTarget = startContainer.parentNode;
+                return new UnknownHitTestResult(startContainer.parentNode);
             }
         }
         else if (startContainer.nodeType === startContainer.ELEMENT_NODE) {
@@ -633,20 +664,13 @@ export class MouseTargetFactory {
             const parent2 = parent1 ? parent1.parentNode : null; // expected to be the view line div
             const parent2ClassName = parent2 && parent2.nodeType === parent2.ELEMENT_NODE ? parent2.className : null;
             if (parent2ClassName === ViewLine.CLASS_NAME) {
-                const p = ctx.getPositionFromDOMInfo(startContainer, startContainer.textContent.length);
-                return {
-                    position: p,
-                    hitTarget: null
-                };
+                return HitTestResult.createFromDOMInfo(ctx, startContainer, startContainer.textContent.length);
             }
             else {
-                hitTarget = startContainer;
+                return new UnknownHitTestResult(startContainer);
             }
         }
-        return {
-            position: null,
-            hitTarget: hitTarget
-        };
+        return new UnknownHitTestResult();
     }
     /**
      * Most probably Gecko
@@ -660,110 +684,55 @@ export class MouseTargetFactory {
             const parent3 = parent2 ? parent2.parentNode : null; // expected to be the view line div
             const parent3ClassName = parent3 && parent3.nodeType === parent3.ELEMENT_NODE ? parent3.className : null;
             if (parent3ClassName === ViewLine.CLASS_NAME) {
-                const p = ctx.getPositionFromDOMInfo(hitResult.offsetNode.parentNode, hitResult.offset);
-                return {
-                    position: p,
-                    hitTarget: null
-                };
+                return HitTestResult.createFromDOMInfo(ctx, hitResult.offsetNode.parentNode, hitResult.offset);
             }
             else {
-                return {
-                    position: null,
-                    hitTarget: hitResult.offsetNode.parentNode
-                };
+                return new UnknownHitTestResult(hitResult.offsetNode.parentNode);
             }
         }
-        // For inline decorations, Gecko returns the `<span>` of the line and the offset is the `<span>` with the inline decoration
+        // For inline decorations, Gecko sometimes returns the `<span>` of the line and the offset is the `<span>` with the inline decoration
+        // Some other times, it returns the `<span>` with the inline decoration
         if (hitResult.offsetNode.nodeType === hitResult.offsetNode.ELEMENT_NODE) {
-            const parent1 = hitResult.offsetNode.parentNode; // expected to be the view line div
+            const parent1 = hitResult.offsetNode.parentNode;
             const parent1ClassName = parent1 && parent1.nodeType === parent1.ELEMENT_NODE ? parent1.className : null;
+            const parent2 = parent1 ? parent1.parentNode : null;
+            const parent2ClassName = parent2 && parent2.nodeType === parent2.ELEMENT_NODE ? parent2.className : null;
             if (parent1ClassName === ViewLine.CLASS_NAME) {
+                // it returned the `<span>` of the line and the offset is the `<span>` with the inline decoration
                 const tokenSpan = hitResult.offsetNode.childNodes[Math.min(hitResult.offset, hitResult.offsetNode.childNodes.length - 1)];
                 if (tokenSpan) {
-                    const p = ctx.getPositionFromDOMInfo(tokenSpan, 0);
-                    return {
-                        position: p,
-                        hitTarget: null
-                    };
+                    return HitTestResult.createFromDOMInfo(ctx, tokenSpan, 0);
                 }
             }
+            else if (parent2ClassName === ViewLine.CLASS_NAME) {
+                // it returned the `<span>` with the inline decoration
+                return HitTestResult.createFromDOMInfo(ctx, hitResult.offsetNode, 0);
+            }
         }
-        return {
-            position: null,
-            hitTarget: hitResult.offsetNode
-        };
+        return new UnknownHitTestResult(hitResult.offsetNode);
     }
-    /**
-     * Most probably IE
-     */
-    static _doHitTestWithMoveToPoint(ctx, coords) {
-        let resultPosition = null;
-        let resultHitTarget = null;
-        const textRange = document.body.createTextRange();
-        try {
-            textRange.moveToPoint(coords.clientX, coords.clientY);
+    static _snapToSoftTabBoundary(position, viewModel) {
+        const lineContent = viewModel.getLineContent(position.lineNumber);
+        const { tabSize } = viewModel.getTextModelOptions();
+        const newPosition = AtomicTabMoveOperations.atomicPosition(lineContent, position.column - 1, tabSize, 2 /* Nearest */);
+        if (newPosition !== -1) {
+            return new Position(position.lineNumber, newPosition + 1);
         }
-        catch (err) {
-            return {
-                position: null,
-                hitTarget: null
-            };
-        }
-        textRange.collapse(true);
-        // Now, let's do our best to figure out what we hit :)
-        const parentElement = textRange ? textRange.parentElement() : null;
-        const parent1 = parentElement ? parentElement.parentNode : null;
-        const parent2 = parent1 ? parent1.parentNode : null;
-        const parent2ClassName = parent2 && parent2.nodeType === parent2.ELEMENT_NODE ? parent2.className : '';
-        if (parent2ClassName === ViewLine.CLASS_NAME) {
-            const rangeToContainEntireSpan = textRange.duplicate();
-            rangeToContainEntireSpan.moveToElementText(parentElement);
-            rangeToContainEntireSpan.setEndPoint('EndToStart', textRange);
-            resultPosition = ctx.getPositionFromDOMInfo(parentElement, rangeToContainEntireSpan.text.length);
-            // Move range out of the span node, IE doesn't like having many ranges in
-            // the same spot and will act badly for lines containing dashes ('-')
-            rangeToContainEntireSpan.moveToElementText(ctx.viewDomNode);
-        }
-        else {
-            // Looks like we've hit the hover or something foreign
-            resultHitTarget = parentElement;
-        }
-        // Move range out of the span node, IE doesn't like having many ranges in
-        // the same spot and will act badly for lines containing dashes ('-')
-        textRange.moveToElementText(ctx.viewDomNode);
-        return {
-            position: resultPosition,
-            hitTarget: resultHitTarget
-        };
+        return position;
     }
     static _doHitTest(ctx, request) {
-        // State of the art (18.10.2012):
-        // The spec says browsers should support document.caretPositionFromPoint, but nobody implemented it (http://dev.w3.org/csswg/cssom-view/)
-        // Gecko:
-        //    - they tried to implement it once, but failed: https://bugzilla.mozilla.org/show_bug.cgi?id=654352
-        //    - however, they do give out rangeParent/rangeOffset properties on mouse events
-        // Webkit:
-        //    - they have implemented a previous version of the spec which was using document.caretRangeFromPoint
-        // IE:
-        //    - they have a proprietary method on ranges, moveToPoint: https://msdn.microsoft.com/en-us/library/ie/ms536632(v=vs.85).aspx
-        // 24.08.2016: Edge has added WebKit's document.caretRangeFromPoint, but it is quite buggy
-        //    - when hit testing the cursor it returns the first or the last line in the viewport
-        //    - it inconsistently hits text nodes or span nodes, while WebKit only hits text nodes
-        //    - when toggling render whitespace on, and hit testing in the empty content after a line, it always hits offset 0 of the first span of the line
-        // Thank you browsers for making this so 'easy' :)
+        let result = new UnknownHitTestResult();
         if (typeof document.caretRangeFromPoint === 'function') {
-            return this._doHitTestWithCaretRangeFromPoint(ctx, request);
+            result = this._doHitTestWithCaretRangeFromPoint(ctx, request);
         }
         else if (document.caretPositionFromPoint) {
-            return this._doHitTestWithCaretPositionFromPoint(ctx, request.pos.toClientCoordinates());
+            result = this._doHitTestWithCaretPositionFromPoint(ctx, request.pos.toClientCoordinates());
         }
-        else if (document.body.createTextRange) {
-            return this._doHitTestWithMoveToPoint(ctx, request.pos.toClientCoordinates());
+        // Snap to the nearest soft tab boundary if atomic soft tabs are enabled.
+        if (result.type === 1 /* Content */ && ctx.stickyTabStops) {
+            result = new ContentHitTestResult(this._snapToSoftTabBoundary(result.position, ctx.model), result.spanNode);
         }
-        return {
-            position: null,
-            hitTarget: null
-        };
+        return result;
     }
 }
 export function shadowCaretRangeFromPoint(shadowRoot, x, y) {
@@ -774,7 +743,7 @@ export function shadowCaretRangeFromPoint(shadowRoot, x, y) {
         // Get the last child of the element until its firstChild is a text node
         // This assumes that the pointer is on the right of the line, out of the tokens
         // and that we want to get the offset of the last token of the line
-        while (el && el.firstChild && el.firstChild.nodeType !== el.firstChild.TEXT_NODE) {
+        while (el && el.firstChild && el.firstChild.nodeType !== el.firstChild.TEXT_NODE && el.lastChild && el.lastChild.firstChild) {
             el = el.lastChild;
         }
         // Grab its rect
