@@ -4,6 +4,7 @@
  *--------------------------------------------------------------------------------------------*/
 import * as strings from '../../../base/common/strings.js';
 import { SingleCursorState } from './cursorCommon.js';
+import { DeleteOperations } from './cursorDeleteOperations.js';
 import { getMapForWordSeparators } from './wordCharacterClassifier.js';
 import { Position } from '../core/position.js';
 import { Range } from '../core/range.js';
@@ -276,10 +277,18 @@ export class WordOperations {
         }
         return null;
     }
-    static deleteWordLeft(wordSeparators, model, selection, whitespaceHeuristics, wordNavigationType) {
+    static deleteWordLeft(ctx, wordNavigationType) {
+        const wordSeparators = ctx.wordSeparators;
+        const model = ctx.model;
+        const selection = ctx.selection;
+        const whitespaceHeuristics = ctx.whitespaceHeuristics;
         if (!selection.isEmpty()) {
             return selection;
         }
+        if (DeleteOperations.isAutoClosingPairDelete(ctx.autoClosingDelete, ctx.autoClosingBrackets, ctx.autoClosingQuotes, ctx.autoClosingPairs.autoClosingPairsOpenByEnd, ctx.model, [ctx.selection], ctx.autoClosedCharacters)) {
+            const position = ctx.selection.getPosition();
+            return new Range(position.lineNumber, position.column - 1, position.lineNumber, position.column + 1);
+        }
         const position = new Position(selection.positionLineNumber, selection.positionColumn);
         let lineNumber = position.lineNumber;
         let column = position.column;
@@ -327,6 +336,108 @@ export class WordOperations {
         }
         return new Range(lineNumber, column, position.lineNumber, position.column);
     }
+    static deleteInsideWord(wordSeparators, model, selection) {
+        if (!selection.isEmpty()) {
+            return selection;
+        }
+        const position = new Position(selection.positionLineNumber, selection.positionColumn);
+        let r = this._deleteInsideWordWhitespace(model, position);
+        if (r) {
+            return r;
+        }
+        return this._deleteInsideWordDetermineDeleteRange(wordSeparators, model, position);
+    }
+    static _charAtIsWhitespace(str, index) {
+        const charCode = str.charCodeAt(index);
+        return (charCode === 32 /* Space */ || charCode === 9 /* Tab */);
+    }
+    static _deleteInsideWordWhitespace(model, position) {
+        const lineContent = model.getLineContent(position.lineNumber);
+        const lineContentLength = lineContent.length;
+        if (lineContentLength === 0) {
+            // empty line
+            return null;
+        }
+        let leftIndex = Math.max(position.column - 2, 0);
+        if (!this._charAtIsWhitespace(lineContent, leftIndex)) {
+            // touches a non-whitespace character to the left
+            return null;
+        }
+        let rightIndex = Math.min(position.column - 1, lineContentLength - 1);
+        if (!this._charAtIsWhitespace(lineContent, rightIndex)) {
+            // touches a non-whitespace character to the right
+            return null;
+        }
+        // walk over whitespace to the left
+        while (leftIndex > 0 && this._charAtIsWhitespace(lineContent, leftIndex - 1)) {
+            leftIndex--;
+        }
+        // walk over whitespace to the right
+        while (rightIndex + 1 < lineContentLength && this._charAtIsWhitespace(lineContent, rightIndex + 1)) {
+            rightIndex++;
+        }
+        return new Range(position.lineNumber, leftIndex + 1, position.lineNumber, rightIndex + 2);
+    }
+    static _deleteInsideWordDetermineDeleteRange(wordSeparators, model, position) {
+        const lineContent = model.getLineContent(position.lineNumber);
+        const lineLength = lineContent.length;
+        if (lineLength === 0) {
+            // empty line
+            if (position.lineNumber > 1) {
+                return new Range(position.lineNumber - 1, model.getLineMaxColumn(position.lineNumber - 1), position.lineNumber, 1);
+            }
+            else {
+                if (position.lineNumber < model.getLineCount()) {
+                    return new Range(position.lineNumber, 1, position.lineNumber + 1, 1);
+                }
+                else {
+                    // empty model
+                    return new Range(position.lineNumber, 1, position.lineNumber, 1);
+                }
+            }
+        }
+        const touchesWord = (word) => {
+            return (word.start + 1 <= position.column && position.column <= word.end + 1);
+        };
+        const createRangeWithPosition = (startColumn, endColumn) => {
+            startColumn = Math.min(startColumn, position.column);
+            endColumn = Math.max(endColumn, position.column);
+            return new Range(position.lineNumber, startColumn, position.lineNumber, endColumn);
+        };
+        const deleteWordAndAdjacentWhitespace = (word) => {
+            let startColumn = word.start + 1;
+            let endColumn = word.end + 1;
+            let expandedToTheRight = false;
+            while (endColumn - 1 < lineLength && this._charAtIsWhitespace(lineContent, endColumn - 1)) {
+                expandedToTheRight = true;
+                endColumn++;
+            }
+            if (!expandedToTheRight) {
+                while (startColumn > 1 && this._charAtIsWhitespace(lineContent, startColumn - 2)) {
+                    startColumn--;
+                }
+            }
+            return createRangeWithPosition(startColumn, endColumn);
+        };
+        const prevWordOnLine = WordOperations._findPreviousWordOnLine(wordSeparators, model, position);
+        if (prevWordOnLine && touchesWord(prevWordOnLine)) {
+            return deleteWordAndAdjacentWhitespace(prevWordOnLine);
+        }
+        const nextWordOnLine = WordOperations._findNextWordOnLine(wordSeparators, model, position);
+        if (nextWordOnLine && touchesWord(nextWordOnLine)) {
+            return deleteWordAndAdjacentWhitespace(nextWordOnLine);
+        }
+        if (prevWordOnLine && nextWordOnLine) {
+            return createRangeWithPosition(prevWordOnLine.end + 1, nextWordOnLine.start + 1);
+        }
+        if (prevWordOnLine) {
+            return createRangeWithPosition(prevWordOnLine.start + 1, prevWordOnLine.end + 1);
+        }
+        if (nextWordOnLine) {
+            return createRangeWithPosition(nextWordOnLine.start + 1, nextWordOnLine.end + 1);
+        }
+        return createRangeWithPosition(1, lineLength + 1);
+    }
     static _deleteWordPartLeft(model, selection) {
         if (!selection.isEmpty()) {
             return selection;
@@ -355,7 +466,11 @@ export class WordOperations {
         }
         return null;
     }
-    static deleteWordRight(wordSeparators, model, selection, whitespaceHeuristics, wordNavigationType) {
+    static deleteWordRight(ctx, wordNavigationType) {
+        const wordSeparators = ctx.wordSeparators;
+        const model = ctx.model;
+        const selection = ctx.selection;
+        const whitespaceHeuristics = ctx.whitespaceHeuristics;
         if (!selection.isEmpty()) {
             return selection;
         }
@@ -521,20 +636,20 @@ export class WordOperations {
     }
 }
 export class WordPartOperations extends WordOperations {
-    static deleteWordPartLeft(wordSeparators, model, selection, whitespaceHeuristics) {
+    static deleteWordPartLeft(ctx) {
         const candidates = enforceDefined([
-            WordOperations.deleteWordLeft(wordSeparators, model, selection, whitespaceHeuristics, 0 /* WordStart */),
-            WordOperations.deleteWordLeft(wordSeparators, model, selection, whitespaceHeuristics, 2 /* WordEnd */),
-            WordOperations._deleteWordPartLeft(model, selection)
+            WordOperations.deleteWordLeft(ctx, 0 /* WordStart */),
+            WordOperations.deleteWordLeft(ctx, 2 /* WordEnd */),
+            WordOperations._deleteWordPartLeft(ctx.model, ctx.selection)
         ]);
         candidates.sort(Range.compareRangesUsingEnds);
         return candidates[2];
     }
-    static deleteWordPartRight(wordSeparators, model, selection, whitespaceHeuristics) {
+    static deleteWordPartRight(ctx) {
         const candidates = enforceDefined([
-            WordOperations.deleteWordRight(wordSeparators, model, selection, whitespaceHeuristics, 0 /* WordStart */),
-            WordOperations.deleteWordRight(wordSeparators, model, selection, whitespaceHeuristics, 2 /* WordEnd */),
-            WordOperations._deleteWordPartRight(model, selection)
+            WordOperations.deleteWordRight(ctx, 0 /* WordStart */),
+            WordOperations.deleteWordRight(ctx, 2 /* WordEnd */),
+            WordOperations._deleteWordPartRight(ctx.model, ctx.selection)
         ]);
         candidates.sort(Range.compareRangesUsingStarts);
         return candidates[0];
