@@ -22,11 +22,11 @@ var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, ge
 };
 import { RunOnceScheduler, createCancelablePromise, disposableTimeout } from '../../../base/common/async.js';
 import { onUnexpectedError, onUnexpectedExternalError } from '../../../base/common/errors.js';
-import { toDisposable, DisposableStore, dispose } from '../../../base/common/lifecycle.js';
+import { toDisposable, DisposableStore } from '../../../base/common/lifecycle.js';
 import { StableEditorScrollState } from '../../browser/core/editorState.js';
 import { registerEditorContribution, registerEditorAction, EditorAction } from '../../browser/editorExtensions.js';
 import { CodeLensProviderRegistry } from '../../common/modes.js';
-import { getCodeLensData } from './codelens.js';
+import { getCodeLensModel } from './codelens.js';
 import { CodeLensWidget, CodeLensHelper } from './codelensWidget.js';
 import { ICommandService } from '../../../platform/commands/common/commands.js';
 import { INotificationService } from '../../../platform/notification/common/notification.js';
@@ -36,33 +36,31 @@ import { hash } from '../../../base/common/hash.js';
 import { IQuickInputService } from '../../../platform/quickinput/common/quickInput.js';
 import { localize } from '../../../nls.js';
 import { EditorContextKeys } from '../../common/editorContextKeys.js';
+import { LanguageFeatureRequestDelays } from '../../common/modes/languageFeatureRegistry.js';
 let CodeLensContribution = class CodeLensContribution {
     constructor(_editor, _commandService, _notificationService, _codeLensCache) {
         this._editor = _editor;
         this._commandService = _commandService;
         this._notificationService = _notificationService;
         this._codeLensCache = _codeLensCache;
-        this._globalToDispose = new DisposableStore();
+        this._disposables = new DisposableStore();
         this._localToDispose = new DisposableStore();
         this._lenses = [];
+        this._getCodeLensModelDelays = new LanguageFeatureRequestDelays(CodeLensProviderRegistry, 250, 2500);
         this._oldCodeLensModels = new DisposableStore();
-        this._modelChangeCounter = 0;
-        this._isEnabled = this._editor.getOption(11 /* codeLens */);
-        this._globalToDispose.add(this._editor.onDidChangeModel(() => this._onModelChange()));
-        this._globalToDispose.add(this._editor.onDidChangeModelLanguage(() => this._onModelChange()));
-        this._globalToDispose.add(this._editor.onDidChangeConfiguration(() => {
-            const prevIsEnabled = this._isEnabled;
-            this._isEnabled = this._editor.getOption(11 /* codeLens */);
-            if (prevIsEnabled !== this._isEnabled) {
+        this._resolveCodeLensesDelays = new LanguageFeatureRequestDelays(CodeLensProviderRegistry, 250, 2500);
+        this._resolveCodeLensesScheduler = new RunOnceScheduler(() => this._resolveCodeLensesInViewport(), this._resolveCodeLensesDelays.min);
+        this._disposables.add(this._editor.onDidChangeModel(() => this._onModelChange()));
+        this._disposables.add(this._editor.onDidChangeModelLanguage(() => this._onModelChange()));
+        this._disposables.add(this._editor.onDidChangeConfiguration((e) => {
+            if (e.hasChanged(40 /* fontInfo */) || e.hasChanged(14 /* codeLensFontSize */) || e.hasChanged(13 /* codeLensFontFamily */)) {
+                this._updateLensStyle();
+            }
+            if (e.hasChanged(12 /* codeLens */)) {
                 this._onModelChange();
             }
         }));
-        this._globalToDispose.add(CodeLensProviderRegistry.onDidChange(this._onModelChange, this));
-        this._globalToDispose.add(this._editor.onDidChangeConfiguration(e => {
-            if (e.hasChanged(36 /* fontInfo */)) {
-                this._updateLensStyle();
-            }
-        }));
+        this._disposables.add(CodeLensProviderRegistry.onDidChange(this._onModelChange, this));
         this._onModelChange();
         this._styleClassName = '_' + hash(this._editor.getId()).toString(16);
         this._styleElement = dom.createStyleSheet(dom.isInShadowDOM(this._editor.getContainerDomNode())
@@ -71,36 +69,57 @@ let CodeLensContribution = class CodeLensContribution {
         this._updateLensStyle();
     }
     dispose() {
+        var _a;
         this._localDispose();
-        this._globalToDispose.dispose();
+        this._disposables.dispose();
         this._oldCodeLensModels.dispose();
-        dispose(this._currentCodeLensModel);
+        (_a = this._currentCodeLensModel) === null || _a === void 0 ? void 0 : _a.dispose();
+        this._styleElement.remove();
+    }
+    _getLayoutInfo() {
+        let fontSize = this._editor.getOption(14 /* codeLensFontSize */);
+        let codeLensHeight;
+        if (!fontSize || fontSize < 5) {
+            fontSize = (this._editor.getOption(42 /* fontSize */) * .9) | 0;
+            codeLensHeight = this._editor.getOption(56 /* lineHeight */);
+        }
+        else {
+            codeLensHeight = (fontSize * Math.max(1.3, this._editor.getOption(56 /* lineHeight */) / this._editor.getOption(42 /* fontSize */))) | 0;
+        }
+        return { codeLensHeight, fontSize };
     }
     _updateLensStyle() {
-        const options = this._editor.getOptions();
-        const fontInfo = options.get(36 /* fontInfo */);
-        const lineHeight = options.get(51 /* lineHeight */);
-        const height = Math.round(lineHeight * 1.1);
-        const fontSize = Math.round(fontInfo.fontSize * 0.9);
-        const newStyle = `
-		.monaco-editor .codelens-decoration.${this._styleClassName} { height: ${height}px; line-height: ${lineHeight}px; font-size: ${fontSize}px; padding-right: ${Math.round(fontInfo.fontSize * 0.45)}px;}
-		.monaco-editor .codelens-decoration.${this._styleClassName} > a > .codicon { line-height: ${lineHeight}px; font-size: ${fontSize}px; }
+        const { codeLensHeight, fontSize } = this._getLayoutInfo();
+        const fontFamily = this._editor.getOption(13 /* codeLensFontFamily */);
+        const editorFontInfo = this._editor.getOption(40 /* fontInfo */);
+        const fontFamilyVar = `--codelens-font-family${this._styleClassName}`;
+        const fontFeaturesVar = `--codelens-font-features${this._styleClassName}`;
+        let newStyle = `
+		.monaco-editor .codelens-decoration.${this._styleClassName} { line-height: ${codeLensHeight}px; font-size: ${fontSize}px; padding-right: ${Math.round(fontSize * 0.5)}px; font-feature-settings: var(${fontFeaturesVar}) }
+		.monaco-editor .codelens-decoration.${this._styleClassName} span.codicon { line-height: ${codeLensHeight}px; font-size: ${fontSize}px; }
 		`;
+        if (fontFamily) {
+            newStyle += `.monaco-editor .codelens-decoration.${this._styleClassName} { font-family: var(${fontFamilyVar})}`;
+        }
         this._styleElement.textContent = newStyle;
+        this._editor.getContainerDomNode().style.setProperty(fontFamilyVar, fontFamily !== null && fontFamily !== void 0 ? fontFamily : 'inherit');
+        this._editor.getContainerDomNode().style.setProperty(fontFeaturesVar, editorFontInfo.fontFeatureSettings);
+        //
+        this._editor.changeViewZones(accessor => {
+            for (let lens of this._lenses) {
+                lens.updateHeight(codeLensHeight, accessor);
+            }
+        });
     }
     _localDispose() {
-        if (this._currentFindCodeLensSymbolsPromise) {
-            this._currentFindCodeLensSymbolsPromise.cancel();
-            this._currentFindCodeLensSymbolsPromise = undefined;
-            this._modelChangeCounter++;
-        }
-        if (this._currentResolveCodeLensSymbolsPromise) {
-            this._currentResolveCodeLensSymbolsPromise.cancel();
-            this._currentResolveCodeLensSymbolsPromise = undefined;
-        }
+        var _a, _b, _c;
+        (_a = this._getCodeLensModelPromise) === null || _a === void 0 ? void 0 : _a.cancel();
+        this._getCodeLensModelPromise = undefined;
+        (_b = this._resolveCodeLensesPromise) === null || _b === void 0 ? void 0 : _b.cancel();
+        this._resolveCodeLensesPromise = undefined;
         this._localToDispose.clear();
         this._oldCodeLensModels.clear();
-        dispose(this._currentCodeLensModel);
+        (_c = this._currentCodeLensModel) === null || _c === void 0 ? void 0 : _c.dispose();
     }
     _onModelChange() {
         this._localDispose();
@@ -108,7 +127,7 @@ let CodeLensContribution = class CodeLensContribution {
         if (!model) {
             return;
         }
-        if (!this._isEnabled) {
+        if (!this._editor.getOption(12 /* codeLens */)) {
             return;
         }
         const cachedLenses = this._codeLensCache.get(model);
@@ -135,29 +154,28 @@ let CodeLensContribution = class CodeLensContribution {
                 this._localToDispose.add(registration);
             }
         }
-        const detectVisibleLenses = this._detectVisibleLenses = new RunOnceScheduler(() => this._onViewportChanged(), 250);
         const scheduler = new RunOnceScheduler(() => {
-            const counterValue = ++this._modelChangeCounter;
-            if (this._currentFindCodeLensSymbolsPromise) {
-                this._currentFindCodeLensSymbolsPromise.cancel();
-            }
-            this._currentFindCodeLensSymbolsPromise = createCancelablePromise(token => getCodeLensData(model, token));
-            this._currentFindCodeLensSymbolsPromise.then(result => {
-                if (counterValue === this._modelChangeCounter) { // only the last one wins
-                    if (this._currentCodeLensModel) {
-                        this._oldCodeLensModels.add(this._currentCodeLensModel);
-                    }
-                    this._currentCodeLensModel = result;
-                    // cache model to reduce flicker
-                    this._codeLensCache.put(model, result);
-                    // render lenses
-                    this._renderCodeLensSymbols(result);
-                    detectVisibleLenses.schedule();
+            var _a;
+            const t1 = Date.now();
+            (_a = this._getCodeLensModelPromise) === null || _a === void 0 ? void 0 : _a.cancel();
+            this._getCodeLensModelPromise = createCancelablePromise(token => getCodeLensModel(model, token));
+            this._getCodeLensModelPromise.then(result => {
+                if (this._currentCodeLensModel) {
+                    this._oldCodeLensModels.add(this._currentCodeLensModel);
                 }
+                this._currentCodeLensModel = result;
+                // cache model to reduce flicker
+                this._codeLensCache.put(model, result);
+                // update moving average
+                const newDelay = this._getCodeLensModelDelays.update(model, Date.now() - t1);
+                scheduler.delay = newDelay;
+                // render lenses
+                this._renderCodeLensSymbols(result);
+                this._resolveCodeLensesInViewport();
             }, onUnexpectedError);
-        }, 250);
+        }, this._getCodeLensModelDelays.get(model));
         this._localToDispose.add(scheduler);
-        this._localToDispose.add(detectVisibleLenses);
+        this._localToDispose.add(toDisposable(() => this._resolveCodeLensesScheduler.cancel()));
         this._localToDispose.add(this._editor.onDidChangeModelContent(() => {
             this._editor.changeDecorations(decorationsAccessor => {
                 this._editor.changeViewZones(viewZonesAccessor => {
@@ -182,18 +200,19 @@ let CodeLensContribution = class CodeLensContribution {
                     helper.commit(decorationsAccessor);
                 });
             });
-            // Compute new `visible` code lenses
-            detectVisibleLenses.schedule();
             // Ask for all references again
             scheduler.schedule();
         }));
+        this._localToDispose.add(this._editor.onDidFocusEditorWidget(() => {
+            scheduler.schedule();
+        }));
         this._localToDispose.add(this._editor.onDidScrollChange(e => {
             if (e.scrollTopChanged && this._lenses.length > 0) {
-                detectVisibleLenses.schedule();
+                this._resolveCodeLensesInViewportSoon();
             }
         }));
         this._localToDispose.add(this._editor.onDidLayoutChange(() => {
-            detectVisibleLenses.schedule();
+            this._resolveCodeLensesInViewportSoon();
         }));
         this._localToDispose.add(toDisposable(() => {
             if (this._editor.getModel()) {
@@ -210,7 +229,7 @@ let CodeLensContribution = class CodeLensContribution {
                 this._disposeAllLenses(undefined, undefined);
             }
         }));
-        this._localToDispose.add(this._editor.onMouseUp(e => {
+        this._localToDispose.add(this._editor.onMouseDown(e => {
             if (e.target.type !== 9 /* CONTENT_WIDGET */) {
                 return;
             }
@@ -238,7 +257,7 @@ let CodeLensContribution = class CodeLensContribution {
         if (decChangeAccessor) {
             helper.commit(decChangeAccessor);
         }
-        this._lenses = [];
+        this._lenses.length = 0;
     }
     _renderCodeLensSymbols(symbols) {
         if (!this._editor.hasModel()) {
@@ -264,6 +283,7 @@ let CodeLensContribution = class CodeLensContribution {
             }
         }
         const scrollState = StableEditorScrollState.capture(this._editor);
+        const layoutInfo = this._getLayoutInfo();
         this._editor.changeDecorations(decorationsAccessor => {
             this._editor.changeViewZones(viewZoneAccessor => {
                 const helper = new CodeLensHelper();
@@ -282,7 +302,7 @@ let CodeLensContribution = class CodeLensContribution {
                         codeLensIndex++;
                     }
                     else {
-                        this._lenses.splice(codeLensIndex, 0, new CodeLensWidget(groups[groupsIndex], this._editor, this._styleClassName, helper, viewZoneAccessor, () => this._detectVisibleLenses && this._detectVisibleLenses.schedule()));
+                        this._lenses.splice(codeLensIndex, 0, new CodeLensWidget(groups[groupsIndex], this._editor, this._styleClassName, helper, viewZoneAccessor, layoutInfo.codeLensHeight, () => this._resolveCodeLensesInViewportSoon()));
                         codeLensIndex++;
                         groupsIndex++;
                     }
@@ -294,7 +314,7 @@ let CodeLensContribution = class CodeLensContribution {
                 }
                 // Create extra symbols
                 while (groupsIndex < groups.length) {
-                    this._lenses.push(new CodeLensWidget(groups[groupsIndex], this._editor, this._styleClassName, helper, viewZoneAccessor, () => this._detectVisibleLenses && this._detectVisibleLenses.schedule()));
+                    this._lenses.push(new CodeLensWidget(groups[groupsIndex], this._editor, this._styleClassName, helper, viewZoneAccessor, layoutInfo.codeLensHeight, () => this._resolveCodeLensesInViewportSoon()));
                     groupsIndex++;
                 }
                 helper.commit(decorationsAccessor);
@@ -302,11 +322,16 @@ let CodeLensContribution = class CodeLensContribution {
         });
         scrollState.restore(this._editor);
     }
-    _onViewportChanged() {
-        if (this._currentResolveCodeLensSymbolsPromise) {
-            this._currentResolveCodeLensSymbolsPromise.cancel();
-            this._currentResolveCodeLensSymbolsPromise = undefined;
+    _resolveCodeLensesInViewportSoon() {
+        const model = this._editor.getModel();
+        if (model) {
+            this._resolveCodeLensesScheduler.schedule();
         }
+    }
+    _resolveCodeLensesInViewport() {
+        var _a;
+        (_a = this._resolveCodeLensesPromise) === null || _a === void 0 ? void 0 : _a.cancel();
+        this._resolveCodeLensesPromise = undefined;
         const model = this._editor.getModel();
         if (!model) {
             return;
@@ -323,6 +348,7 @@ let CodeLensContribution = class CodeLensContribution {
         if (toResolve.length === 0) {
             return;
         }
+        const t1 = Date.now();
         const resolvePromise = createCancelablePromise(token => {
             const promises = toResolve.map((request, i) => {
                 const resolvedSymbols = new Array(request.length);
@@ -345,19 +371,22 @@ let CodeLensContribution = class CodeLensContribution {
             });
             return Promise.all(promises);
         });
-        this._currentResolveCodeLensSymbolsPromise = resolvePromise;
-        this._currentResolveCodeLensSymbolsPromise.then(() => {
+        this._resolveCodeLensesPromise = resolvePromise;
+        this._resolveCodeLensesPromise.then(() => {
+            // update moving average
+            const newDelay = this._resolveCodeLensesDelays.update(model, Date.now() - t1);
+            this._resolveCodeLensesScheduler.delay = newDelay;
             if (this._currentCodeLensModel) { // update the cached state with new resolved items
                 this._codeLensCache.put(model, this._currentCodeLensModel);
             }
             this._oldCodeLensModels.clear(); // dispose old models once we have updated the UI with the current model
-            if (resolvePromise === this._currentResolveCodeLensSymbolsPromise) {
-                this._currentResolveCodeLensSymbolsPromise = undefined;
+            if (resolvePromise === this._resolveCodeLensesPromise) {
+                this._resolveCodeLensesPromise = undefined;
             }
         }, err => {
             onUnexpectedError(err); // can also be cancellation!
-            if (resolvePromise === this._currentResolveCodeLensSymbolsPromise) {
-                this._currentResolveCodeLensSymbolsPromise = undefined;
+            if (resolvePromise === this._resolveCodeLensesPromise) {
+                this._resolveCodeLensesPromise = undefined;
             }
         });
     }
