@@ -3,107 +3,7 @@
  *  Licensed under the MIT License. See License.txt in the project root for license information.
  *--------------------------------------------------------------------------------------------*/
 import * as htmlService from './_deps/vscode-html-languageservice/htmlLanguageService.js';
-import { languages, editor, Uri, Range, MarkerSeverity } from './fillers/monaco-editor-core.js';
-// --- diagnostics --- ---
-var DiagnosticsAdapter = /** @class */ (function () {
-    function DiagnosticsAdapter(_languageId, _worker, defaults) {
-        var _this = this;
-        this._languageId = _languageId;
-        this._worker = _worker;
-        this._disposables = [];
-        this._listener = Object.create(null);
-        var onModelAdd = function (model) {
-            var modeId = model.getModeId();
-            if (modeId !== _this._languageId) {
-                return;
-            }
-            var handle;
-            _this._listener[model.uri.toString()] = model.onDidChangeContent(function () {
-                clearTimeout(handle);
-                handle = setTimeout(function () { return _this._doValidate(model.uri, modeId); }, 500);
-            });
-            _this._doValidate(model.uri, modeId);
-        };
-        var onModelRemoved = function (model) {
-            editor.setModelMarkers(model, _this._languageId, []);
-            var uriStr = model.uri.toString();
-            var listener = _this._listener[uriStr];
-            if (listener) {
-                listener.dispose();
-                delete _this._listener[uriStr];
-            }
-        };
-        this._disposables.push(editor.onDidCreateModel(onModelAdd));
-        this._disposables.push(editor.onWillDisposeModel(function (model) {
-            onModelRemoved(model);
-        }));
-        this._disposables.push(editor.onDidChangeModelLanguage(function (event) {
-            onModelRemoved(event.model);
-            onModelAdd(event.model);
-        }));
-        this._disposables.push(defaults.onDidChange(function (_) {
-            editor.getModels().forEach(function (model) {
-                if (model.getModeId() === _this._languageId) {
-                    onModelRemoved(model);
-                    onModelAdd(model);
-                }
-            });
-        }));
-        this._disposables.push({
-            dispose: function () {
-                for (var key in _this._listener) {
-                    _this._listener[key].dispose();
-                }
-            }
-        });
-        editor.getModels().forEach(onModelAdd);
-    }
-    DiagnosticsAdapter.prototype.dispose = function () {
-        this._disposables.forEach(function (d) { return d && d.dispose(); });
-        this._disposables = [];
-    };
-    DiagnosticsAdapter.prototype._doValidate = function (resource, languageId) {
-        this._worker(resource)
-            .then(function (worker) {
-            return worker.doValidation(resource.toString()).then(function (diagnostics) {
-                var markers = diagnostics.map(function (d) { return toDiagnostics(resource, d); });
-                editor.setModelMarkers(editor.getModel(resource), languageId, markers);
-            });
-        })
-            .then(undefined, function (err) {
-            console.error(err);
-        });
-    };
-    return DiagnosticsAdapter;
-}());
-export { DiagnosticsAdapter };
-function toSeverity(lsSeverity) {
-    switch (lsSeverity) {
-        case htmlService.DiagnosticSeverity.Error:
-            return MarkerSeverity.Error;
-        case htmlService.DiagnosticSeverity.Warning:
-            return MarkerSeverity.Warning;
-        case htmlService.DiagnosticSeverity.Information:
-            return MarkerSeverity.Info;
-        case htmlService.DiagnosticSeverity.Hint:
-            return MarkerSeverity.Hint;
-        default:
-            return MarkerSeverity.Info;
-    }
-}
-function toDiagnostics(resource, diag) {
-    var code = typeof diag.code === 'number' ? String(diag.code) : diag.code;
-    return {
-        severity: toSeverity(diag.severity),
-        startLineNumber: diag.range.start.line + 1,
-        startColumn: diag.range.start.character + 1,
-        endLineNumber: diag.range.end.line + 1,
-        endColumn: diag.range.end.character + 1,
-        message: diag.message,
-        code: code,
-        source: diag.source
-    };
-}
+import { languages, Uri, Range } from './fillers/monaco-editor-core.js';
 // --- completion ------
 function fromPosition(position) {
     if (!position) {
