@@ -4,9 +4,8 @@ const Avvio = require('avvio')
 const http = require('http')
 const querystring = require('querystring')
 let lightMyRequest
-let version
-let versionLoaded = false
 
+const { version } = require('./package.json')
 const {
   kAvvioBoot,
   kChildren,
@@ -15,9 +14,7 @@ const {
   kLogLevel,
   kLogSerializers,
   kHooks,
-  kSchemas,
-  kValidatorCompiler,
-  kSerializerCompiler,
+  kSchemaController,
   kReplySerializerDefault,
   kContentTypeParser,
   kReply,
@@ -36,8 +33,8 @@ const Request = require('./lib/request')
 const supportedMethods = ['DELETE', 'GET', 'HEAD', 'PATCH', 'POST', 'PUT', 'OPTIONS']
 const decorator = require('./lib/decorate')
 const ContentTypeParser = require('./lib/contentTypeParser')
-const { Hooks, hookRunnerApplication } = require('./lib/hooks')
-const { Schemas } = require('./lib/schemas')
+const SchemaController = require('./lib/schema-controller')
+const { Hooks, hookRunnerApplication, supportedHooks } = require('./lib/hooks')
 const { createLogger } = require('./lib/logger')
 const pluginUtils = require('./lib/pluginUtils')
 const reqIdGenFactory = require('./lib/reqIdGenFactory')
@@ -45,6 +42,7 @@ const { buildRouting, validateBodyLimitOption } = require('./lib/route')
 const build404 = require('./lib/fourOhFour')
 const getSecuredInitialConfig = require('./lib/initialConfigValidation')
 const override = require('./lib/pluginOverride')
+const warning = require('./lib/warnings')
 const { defaultInitOptions } = getSecuredInitialConfig
 
 const {
@@ -59,6 +57,19 @@ const onBadUrlContext = {
   onError: []
 }
 
+function defaultBuildPrettyMeta (route) {
+  // return a shallow copy of route's sanitized context
+
+  const cleanKeys = {}
+  const allowedProps = ['errorHandler', 'logLevel', 'logSerializers']
+
+  allowedProps.concat(supportedHooks).forEach(k => {
+    cleanKeys[k] = route.store[k]
+  })
+
+  return Object.assign({}, cleanKeys)
+}
+
 function defaultErrorHandler (error, request, reply) {
   if (reply.statusCode < 500) {
     reply.log.info(
@@ -86,6 +97,10 @@ function fastify (options) {
     throw new Error(`querystringParser option should be a function, instead got '${typeof options.querystringParser}'`)
   }
 
+  if (options.schemaController && options.schemaController.bucket && typeof options.schemaController.bucket !== 'function') {
+    throw new Error(`schemaController.bucket option should be a function, instead got '${typeof options.schemaController.bucket}'`)
+  }
+
   validateBodyLimitOption(options.bodyLimit)
 
   const requestIdHeader = options.requestIdHeader || defaultInitOptions.requestIdHeader
@@ -110,10 +125,6 @@ function fastify (options) {
     throw new Error(`ajv.plugins option should be an array, instead got '${typeof ajvOptions.plugins}'`)
   }
 
-  ajvOptions.plugins = ajvOptions.plugins.map(plugin => {
-    return Array.isArray(plugin) ? plugin : [plugin]
-  })
-
   // Instance Fastify components
   const { logger, hasLogger } = createLogger(options)
 
@@ -132,15 +143,35 @@ function fastify (options) {
 
   const initialConfig = getSecuredInitialConfig(options)
 
+  let constraints = options.constraints
+  if (options.versioning) {
+    warning.emit('FSTDEP009')
+    constraints = {
+      ...constraints,
+      version: {
+        name: 'version',
+        mustMatchWhenDerived: true,
+        storage: options.versioning.storage,
+        deriveConstraint: options.versioning.deriveVersion,
+        validate (value) {
+          if (typeof value !== 'string') {
+            throw new Error('Version constraint should be a string.')
+          }
+        }
+      }
+    }
+  }
+
   // Default router
   const router = buildRouting({
     config: {
       defaultRoute: defaultRoute,
       onBadUrl: onBadUrl,
+      constraints: constraints,
       ignoreTrailingSlash: options.ignoreTrailingSlash || defaultInitOptions.ignoreTrailingSlash,
       maxParamLength: options.maxParamLength || defaultInitOptions.maxParamLength,
       caseSensitive: options.caseSensitive,
-      versioning: options.versioning
+      buildPrettyMeta: defaultBuildPrettyMeta
     }
   })
 
@@ -155,7 +186,7 @@ function fastify (options) {
   const { server, listen } = createServer(options, httpHandler)
 
   const setupResponseListeners = Reply.setupResponseListeners
-  const schemas = new Schemas()
+  const schemaController = SchemaController.buildSchemaController(null, options.schemaController)
 
   // Public API
   const fastify = {
@@ -172,11 +203,9 @@ function fastify (options) {
     [kLogLevel]: '',
     [kLogSerializers]: null,
     [kHooks]: new Hooks(),
-    [kSchemas]: schemas,
-    [kValidatorCompiler]: null,
+    [kSchemaController]: schemaController,
     [kSchemaErrorFormatter]: null,
     [kErrorHandler]: defaultErrorHandler,
-    [kSerializerCompiler]: null,
     [kReplySerializerDefault]: null,
     [kContentTypeParser]: new ContentTypeParser(
       bodyLimit,
@@ -230,10 +259,11 @@ function fastify (options) {
     addHook: addHook,
     // schemas
     addSchema: addSchema,
-    getSchema: schemas.getSchema.bind(schemas),
-    getSchemas: schemas.getSchemas.bind(schemas),
+    getSchema: schemaController.getSchema.bind(schemaController),
+    getSchemas: schemaController.getSchemas.bind(schemaController),
     setValidatorCompiler: setValidatorCompiler,
     setSerializerCompiler: setSerializerCompiler,
+    setSchemaController: setSchemaController,
     setReplySerializer: setReplySerializer,
     setSchemaErrorFormatter: setSchemaErrorFormatter,
     // custom parsers
@@ -247,6 +277,7 @@ function fastify (options) {
     ready: null,
     onClose: null,
     close: null,
+    printPlugins: null,
     // http server
     listen: listen,
     server: server,
@@ -260,7 +291,7 @@ function fastify (options) {
     // fake http injection
     inject: inject,
     // pretty print of the registered routes
-    printRoutes: router.printRoutes,
+    printRoutes,
     // custom error handling
     setNotFoundHandler: setNotFoundHandler,
     setErrorHandler: setErrorHandler,
@@ -268,6 +299,9 @@ function fastify (options) {
     initialConfig
   }
 
+  fastify[kReply].prototype.server = fastify
+  fastify[kRequest].prototype.server = fastify
+
   Object.defineProperties(fastify, {
     pluginName: {
       get () {
@@ -281,16 +315,13 @@ function fastify (options) {
       get () { return this[kRoutePrefix] }
     },
     validatorCompiler: {
-      get () { return this[kValidatorCompiler] }
+      get () { return this[kSchemaController].getValidatorCompiler() }
     },
     serializerCompiler: {
-      get () { return this[kSerializerCompiler] }
+      get () { return this[kSchemaController].getSerializerCompiler() }
     },
     version: {
       get () {
-        if (versionLoaded === false) {
-          version = loadVersion()
-        }
         return version
       }
     },
@@ -330,6 +361,8 @@ function fastify (options) {
   avvio.on('start', () => (fastify[kState].started = true))
   fastify[kAvvioBoot] = fastify.ready // the avvio ready function
   fastify.ready = ready // overwrite the avvio ready function
+  fastify.printPlugins = avvio.prettyPrint.bind(avvio)
+
   // cache the closing value, since we are checking it in an hot path
   avvio.once('preReady', () => {
     fastify.onClose((instance, done) => {
@@ -495,7 +528,7 @@ function fastify (options) {
   // wrapper that we expose to the user for schemas handling
   function addSchema (schema) {
     throwIfAlreadyStarted('Cannot call "addSchema" when fastify instance is already started!')
-    this[kSchemas].add(schema)
+    this[kSchemaController].add(schema)
     this[kChildren].forEach(child => child.addSchema(schema))
     return this
   }
@@ -516,7 +549,7 @@ function fastify (options) {
 
     // Most devs do not know what to do with this error.
     // In the vast majority of cases, it's a network error and/or some
-    // config issue on the the load balancer side.
+    // config issue on the load balancer side.
     this.log.trace({ err }, 'client error')
 
     // If the socket is not writable, there is no reason to try to send data.
@@ -562,7 +595,7 @@ function fastify (options) {
 
   function setValidatorCompiler (validatorCompiler) {
     throwIfAlreadyStarted('Cannot call "setValidatorCompiler" when fastify instance is already started!')
-    this[kValidatorCompiler] = validatorCompiler
+    this[kSchemaController].setValidatorCompiler(validatorCompiler)
     return this
   }
 
@@ -575,7 +608,17 @@ function fastify (options) {
 
   function setSerializerCompiler (serializerCompiler) {
     throwIfAlreadyStarted('Cannot call "setSerializerCompiler" when fastify instance is already started!')
-    this[kSerializerCompiler] = serializerCompiler
+    this[kSchemaController].setSerializerCompiler(serializerCompiler)
+    return this
+  }
+
+  function setSchemaController (schemaControllerOpts) {
+    throwIfAlreadyStarted('Cannot call "setSchemaController" when fastify instance is already started!')
+    const old = this[kSchemaController]
+    const schemaController = SchemaController.buildSchemaController(old.parent, Object.assign({}, old.opts, schemaControllerOpts))
+    this[kSchemaController] = schemaController
+    this.getSchema = schemaController.getSchema.bind(schemaController)
+    this.getSchemas = schemaController.getSchemas.bind(schemaController)
     return this
   }
 
@@ -593,6 +636,12 @@ function fastify (options) {
     this[kErrorHandler] = func.bind(this)
     return this
   }
+
+  function printRoutes (opts = {}) {
+    // includeHooks:true - shortcut to include all supported hooks exported by fastify.Hooks
+    opts.includeMeta = opts.includeHooks ? opts.includeMeta ? supportedHooks.concat(opts.includeMeta) : supportedHooks : opts.includeMeta
+    return router.printRoutes(opts)
+  }
 }
 
 function validateSchemaErrorFormatter (schemaErrorFormatter) {
@@ -622,20 +671,6 @@ function wrapRouting (httpHandler, { rewriteUrl, logger }) {
   }
 }
 
-function loadVersion () {
-  versionLoaded = true
-  const fs = require('fs')
-  const path = require('path')
-  try {
-    const pkgPath = path.join(__dirname, 'package.json')
-    fs.accessSync(pkgPath, fs.constants.R_OK)
-    const pkg = JSON.parse(fs.readFileSync(pkgPath))
-    return pkg.name === 'fastify' ? pkg.version : undefined
-  } catch (e) {
-    return undefined
-  }
-}
-
 /**
  * These export configurations enable JS and TS developers
  * to consumer fastify in whatever way best suits their needs.
