@@ -3,20 +3,30 @@ const { RequestAbortedError } = require('./core/errors')
 const kListener = Symbol('kListener')
 const kSignal = Symbol('kSignal')
 
+function abort (self) {
+  if (self.abort) {
+    self.abort()
+  } else {
+    self.onError(new RequestAbortedError())
+  }
+}
+
 function addSignal (self, signal) {
-  self[kSignal] = signal
+  self[kSignal] = null
   self[kListener] = null
 
   if (!signal) {
     return
   }
 
+  if (signal.aborted) {
+    abort(self)
+    return
+  }
+
+  self[kSignal] = signal
   self[kListener] = () => {
-    if (self.abort) {
-      self.abort()
-    } else {
-      self.onError(new RequestAbortedError())
-    }
+    abort(self)
   }
 
   if ('addEventListener' in self[kSignal]) {
