@@ -13,34 +13,34 @@ import { getNodeFromTree } from '../../core/utils';
  * @return {Mixed}  String of visible text, or `null` if no label is found
  */
 function labelVirtual(virtualNode) {
-	let ref, candidate;
+  let ref, candidate;
 
-	if (virtualNode.attr('aria-labelledby')) {
-		// aria-labelledby
-		ref = idrefs(virtualNode.actualNode, 'aria-labelledby');
-		candidate = ref
-			.map(function(thing) {
-				const vNode = getNodeFromTree(thing);
-				return vNode ? visibleVirtual(vNode, true) : '';
-			})
-			.join(' ')
-			.trim();
+  if (virtualNode.attr('aria-labelledby')) {
+    // aria-labelledby
+    ref = idrefs(virtualNode.actualNode, 'aria-labelledby');
+    candidate = ref
+      .map(thing => {
+        const vNode = getNodeFromTree(thing);
+        return vNode ? visibleVirtual(vNode, true) : '';
+      })
+      .join(' ')
+      .trim();
 
-		if (candidate) {
-			return candidate;
-		}
-	}
+    if (candidate) {
+      return candidate;
+    }
+  }
 
-	// aria-label
-	candidate = virtualNode.attr('aria-label');
-	if (candidate) {
-		candidate = sanitize(candidate);
-		if (candidate) {
-			return candidate;
-		}
-	}
+  // aria-label
+  candidate = virtualNode.attr('aria-label');
+  if (candidate) {
+    candidate = sanitize(candidate);
+    if (candidate) {
+      return candidate;
+    }
+  }
 
-	return null;
+  return null;
 }
 
 export default labelVirtual;
