@@ -19,7 +19,7 @@ test('handlers receive correct `this` context', (t) => {
 
   instance.get('/', function (req, reply) {
     t.ok(this.foo)
-    t.is(this.foo, 'foo')
+    t.equal(this.foo, 'foo')
     reply.send()
   })
 
@@ -27,7 +27,7 @@ test('handlers receive correct `this` context', (t) => {
     instance.server.unref()
     if (err) t.threw(err)
     t.ok(instance.foo)
-    t.is(instance.foo, 'foo')
+    t.equal(instance.foo, 'foo')
 
     const address = `http://127.0.0.1:${instance.server.address().port}/`
     http.get(address, () => {}).on('error', t.threw)
@@ -43,7 +43,7 @@ test('handlers have access to the internal context', (t) => {
     t.ok(reply.context.config)
     t.type(reply.context.config, Object)
     t.ok(reply.context.config.foo)
-    t.is(reply.context.config.foo, 'bar')
+    t.equal(reply.context.config.foo, 'bar')
     reply.send()
   })
 
