@@ -29,7 +29,7 @@ test('fastify.all should add all the methods to the same url', t => {
     fastify.inject(options, (err, res) => {
       t.error(err)
       const payload = JSON.parse(res.payload)
-      t.deepEqual(payload, { method: method })
+      t.same(payload, { method: method })
     })
   }
 })
