@@ -11,7 +11,7 @@ const clock = FakeTimers.createClock()
 t.autoend(false)
 
 const target = Fastify()
-t.tearDown(target.close.bind(target))
+t.teardown(target.close.bind(target))
 
 target.get('/', (request, reply) => {
   t.pass('request arrives')
@@ -26,12 +26,12 @@ async function main () {
   await target.listen(0)
 
   const instance = Fastify()
-  t.tearDown(instance.close.bind(instance))
+  t.teardown(instance.close.bind(instance))
 
   instance.register(From, {
     base: `http://localhost:${target.server.address().port}`,
     undici: {
-      requestTimeout: 100
+      headersTimeout: 100
     }
   })
 
@@ -46,7 +46,7 @@ async function main () {
   } catch (err) {
     t.equal(err.response.statusCode, 504)
     t.match(err.response.headers['content-type'], /application\/json/)
-    t.deepEqual(JSON.parse(err.response.body), {
+    t.same(JSON.parse(err.response.body), {
       statusCode: 504,
       error: 'Gateway Timeout',
       message: 'Gateway Timeout'
