@@ -13,13 +13,19 @@ if (process.platform === 'win32') {
   process.exit(0)
 }
 
+const socketPath = `${__filename}.socket`
+const upstream = `unix+http://${querystring.escape(socketPath)}/`
+
 const instance = Fastify()
-instance.register(From)
+instance.register(From, {
+  // Use node core http, unix sockets are not
+  // supported yet.
+  http: true,
+  base: upstream
+})
 
 t.plan(10)
-t.tearDown(instance.close.bind(instance))
-
-const socketPath = `${__filename}.socket`
+t.teardown(instance.close.bind(instance))
 
 try {
   fs.unlinkSync(socketPath)
@@ -37,10 +43,10 @@ const target = http.createServer((req, res) => {
 })
 
 instance.get('/', (request, reply) => {
-  reply.from(`unix+http://${querystring.escape(socketPath)}/hello`)
+  reply.from('hello')
 })
 
-t.tearDown(target.close.bind(target))
+t.teardown(target.close.bind(target))
 
 instance.listen(0, (err) => {
   t.error(err)
